@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -361,7 +366,6 @@ KineticLaw::setFormula (const std::string& formula)
   }
   else
   {
-    ASTNode * math = SBML_parseFormula(formula.c_str());
     if (formula == "")
     {
       mFormula.erase();
@@ -369,8 +373,10 @@ KineticLaw::setFormula (const std::string& formula)
       mMath = NULL;
       return LIBSBML_OPERATION_SUCCESS;
     }
-    else if (math == NULL || !(math->isWellFormedASTNode()))
+    ASTNode * math = SBML_parseFormula(formula.c_str());
+    if (math == NULL || !(math->isWellFormedASTNode()))
     {
+      delete math;
       return LIBSBML_INVALID_OBJECT;
     }
     else
@@ -382,6 +388,7 @@ KineticLaw::setFormula (const std::string& formula)
         delete mMath;
         mMath = NULL;
       }
+      delete math;
       return LIBSBML_OPERATION_SUCCESS;
     }
   }
@@ -552,22 +559,20 @@ KineticLaw::addParameter (const Parameter* p)
     else
     {
       /* hack so this will deal with local parameters */
-      LocalParameter *lp = new LocalParameter(*p);//->getSBMLNamespaces());
+      LocalParameter lp(*p);
 
-      if (!(lp->hasRequiredAttributes()) || !(lp->hasRequiredElements()))
+      if (!(lp.hasRequiredAttributes()) || !(lp.hasRequiredElements()))
       {
         return LIBSBML_INVALID_OBJECT;
       }
-      else if (getLocalParameter(lp->getId()) != NULL)
+      else if (getLocalParameter(lp.getId()) != NULL)
       {
         // an parameter with this id already exists
         return LIBSBML_DUPLICATE_OBJECT_ID;
       }
       else
       {
-
-        mLocalParameters.append(lp);
-
+        mLocalParameters.append(&lp);
         return LIBSBML_OPERATION_SUCCESS;
       }
     }
@@ -1334,7 +1339,8 @@ KineticLaw::readOtherXML (XMLInputStream& stream)
       }
       else
       {
-        logError(OneMathPerKineticLaw, getLevel(), getVersion());
+        logError(OneMathPerKineticLaw, getLevel(), getVersion(),
+          "The <kineticLaw> contains more than one <math> element.");
       }
     }
 
@@ -1591,7 +1597,7 @@ KineticLaw::writeAttributes (XMLOutputStream& stream) const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
 LIBSBML_EXTERN
