@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -94,7 +99,7 @@ Parameter::Parameter (SBMLNamespaces * sbmlns) :
     throw SBMLConstructorException(getElementName(), sbmlns);
   }
 
-  loadPlugins(sbmlns);
+   loadPlugins(sbmlns);
 
   // if level 3 values have no defaults
   if (sbmlns->getLevel() == 3)
@@ -109,6 +114,30 @@ Parameter::Parameter (SBMLNamespaces * sbmlns) :
 }
 
 
+/** @cond doxygenLibsbmlInternal */
+Parameter::Parameter (SBMLNamespaces * sbmlns, bool isLocal) :
+   SBase      ( sbmlns   )
+ , mId        ( ""       )
+ , mName      ( ""       )
+ , mValue     ( 0.0      )
+ , mUnits     ( ""       )
+ , mConstant  ( true     )
+ , mIsSetValue( false    )
+ , mIsSetConstant (false )
+ , mExplicitlySetConstant ( false )
+ , mCalculatingUnits (false)
+{
+  if (!hasValidLevelVersionNamespaceCombination())
+  {
+    throw SBMLConstructorException(getElementName(), sbmlns);
+  }
+
+  // we are creating a L3 LocalParameter so L3 defaults apply
+  mValue = numeric_limits<double>::quiet_NaN();
+}
+/** @endcond */
+
+
 /*
  * Destroys this Parameter.
  */
@@ -552,10 +581,24 @@ Parameter::getDerivedUnitDefinition()
    * OR the object is not yet a child of a model
    */
 
+  if (m == NULL)
+  {
+    return NULL;
+  }
+  else
+  {
+  /* if we have a model calculate all units */
+    if (!m->isPopulatedListFormulaUnitsData())
+    {
+      m->populateListFormulaUnitsData();
+    }
+  }
+
   /* need to distinguish between a global and local parameter
-  * for a global parameter a unit definition will have been created
-  * for a local parameter need to create one based on the units field
-  */
+   * in order to determine the id that will be used
+   * in the ListFormulaUnitsData
+   */
+    
   bool globalParameter = false;
   SBase *parent  = getParentSBMLObject();
   SBase *pparent = (parent) ? parent->getParentSBMLObject() : NULL; 
@@ -564,72 +607,35 @@ Parameter::getDerivedUnitDefinition()
     globalParameter = true;
   }
 
-  /* if we have a model calculate all units */
-  if (m != NULL)
-  {
-    if (!m->isPopulatedListFormulaUnitsData())
-    {
-      m->populateListFormulaUnitsData();
-    }
-  }
-
   std::string id = this->getId();
+  int typecode = getTypeCode();
+
+  if (globalParameter == false)
+  {
+    // need the id of the reaction
+    Reaction * r = static_cast<Reaction*>(getAncestorOfType(SBML_REACTION));
+    
+    // should not get NULL here but just in case
+    if (r == NULL) return NULL;
+    
+    id = getId() + '_' + r->getId();
+    typecode = SBML_LOCAL_PARAMETER;
+  }
 
   if (calculate == true)
   {
-    if (m != NULL)
-    {
-      derivedUD = inferUnits(m, globalParameter);
-    }
+    derivedUD = inferUnits(m, globalParameter);
   }
   else
   {
     /* here we do not want to try to infer the unit from any formula
     * we just use what is given
     */
-    if (m != NULL)
+    if (m->getFormulaUnitsData(id, typecode) != NULL)
     {
-      if (globalParameter)
-      {
-        /* we are global parameter so units might have been set
-         * if not return NULL
-         */
-        if (m->getFormulaUnitsData(id, getTypeCode()) != NULL)
-        {
-          derivedUD = new UnitDefinition(*(m->getFormulaUnitsData(id, 
-                              getTypeCode())->getUnitDefinition()));
-        }
-      }
-      else
-      {
-        std::string units = getUnits();
-        if (units.empty() == false)
-        {
-          if (UnitKind_isValidUnitKindString(units.c_str(), 
-                                getLevel(), getVersion()))
-          {
-            Unit * unit = new Unit(getSBMLNamespaces());
-            unit->setKind(UnitKind_forName(units.c_str()));
-            unit->initDefaults();
-            derivedUD   = new UnitDefinition(getSBMLNamespaces());
+      // we already have the ud in memory return it
 
-            derivedUD->addUnit(unit);
-
-            delete unit;
-          }
-          else
-          {
-            /* must be a unit definition */
-            derivedUD = new UnitDefinition(*(m->getUnitDefinition(units)));
-          }
-        }
-        else
-        {
-          // here we have none but for consistency return a unitDefinition
-          // with no units
-          derivedUD = new UnitDefinition(getSBMLNamespaces());
-        }
-      }
+      derivedUD = m->getFormulaUnitsData(id, typecode)->getUnitDefinition();
     }
   }
 
@@ -1131,7 +1137,7 @@ Parameter::inferUnits(Model* m, bool globalParameter)
     derivedUD = inferUnitsFromKineticLaw(kl, uff, m);
   }
 
-
+  delete uff;
   return derivedUD;
 }
 
@@ -1354,7 +1360,7 @@ Parameter::inferUnitsFromEvent(Event * e, UnitFormulaFormatter *uff, Model *m)
       // usually at this point we check the fud which should represent the
       // LHS
       // delay cannot use the possibleToUseUnitsData function as
-      // for a delay this refers to teh RHS which we know 
+      // for a delay this refers to the RHS which we know 
       // has a variable with undeclared units  SO it will claim it
       // cannot be used
    
@@ -1385,7 +1391,8 @@ Parameter::inferUnitsFromEvent(Event * e, UnitFormulaFormatter *uff, Model *m)
       u->setKind(UNIT_KIND_DIMENSIONLESS);
 
       derivedUD = uff->inferUnitDefinition(dim, math, id);
-      found = true;
+      delete dim;
+      //found = true;
     }
   }              
 
@@ -1633,29 +1640,9 @@ ListOfParameters::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
-/**
- * Creates a new Parameter_t structure using the given SBML @p level
- * and @p version values.
- *
- * @param level an unsigned int, the SBML Level to assign to this
- * Parameter
- *
- * @param version an unsigned int, the SBML Version to assign to this
- * Parameter
- *
- * @return a pointer to the newly created Parameter_t structure.
- *
- * @note Once a Parameter has been added to an SBMLDocument, the @p
- * level and @p version for the document @em override those used to create
- * the Parameter.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * an object to an existing SBMLDocument.
- */
 LIBSBML_EXTERN
 Parameter_t *
 Parameter_create (unsigned int level, unsigned int version)
@@ -1672,23 +1659,6 @@ Parameter_create (unsigned int level, unsigned int version)
 }
 
 
-/**
- * Creates a new Parameter_t structure using the given
- * SBMLNamespaces_t structure.
- *
- * @param sbmlns SBMLNamespaces, a pointer to an SBMLNamespaces structure
- * to assign to this Parameter
- *
- * @return a pointer to the newly created Parameter_t structure.
- *
- * @note Once a Parameter has been added to an SBMLDocument, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the Parameter.  Despite this, the ability to supply the values at creation time
- * is an important aid to creating valid SBML.  Knowledge of the intended SBML
- * Level and Version determine whether it is valid to assign a particular value
- * to an attribute, or whether it is valid to add an object to an existing
- * SBMLDocument.
- */
 LIBSBML_EXTERN
 Parameter_t *
 Parameter_createWithNS (SBMLNamespaces_t* sbmlns)
@@ -1705,11 +1675,6 @@ Parameter_createWithNS (SBMLNamespaces_t* sbmlns)
 }
 
 
-/**
- * Frees the given Parameter_t structure.
- *
- * @param p the Parameter_t structure to be freed.
- */
 LIBSBML_EXTERN
 void
 Parameter_free (Parameter_t *p)
@@ -1718,13 +1683,6 @@ Parameter_free (Parameter_t *p)
 }
 
 
-/**
- * Creates a deep copy of the given Parameter_t structure
- * 
- * @param p the Parameter_t structure to be copied
- * 
- * @return a (deep) copy of the given Parameter_t structure.
- */
 LIBSBML_EXTERN
 Parameter_t *
 Parameter_clone (const Parameter_t *p)
@@ -1733,16 +1691,6 @@ Parameter_clone (const Parameter_t *p)
 }
 
 
-/**
- * Initializes the attributes of this Parameter_t structure to their defaults.
- *
- * The exact results depends on the %SBML Level and Version in use.  The
- * cases are currently the following:
- * 
- * @li (%SBML Level 2 only) constant = 1 (true)
- *
- * @param p the Parameter_t structure to initialize
- */
 LIBSBML_EXTERN
 void
 Parameter_initDefaults (Parameter_t *p)
@@ -1752,15 +1700,6 @@ Parameter_initDefaults (Parameter_t *p)
 }
 
 
-/**
- * Returns a list of XMLNamespaces_t associated with this Parameter_t
- * structure.
- *
- * @param p the Parameter_t structure
- * 
- * @return pointer to the XMLNamespaces_t structure associated with 
- * this SBML object
- */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
 Parameter_getNamespaces(Parameter_t *p)
@@ -1768,13 +1707,6 @@ Parameter_getNamespaces(Parameter_t *p)
   return (p != NULL) ? p->getNamespaces() : NULL;
 }
 
-/**
- * Takes a Parameter_t structure and returns its identifier.
- *
- * @param p the Parameter_t structure whose identifier is sought
- * 
- * @return the identifier of this Parameter_t, as a pointer to a string.
- */
 LIBSBML_EXTERN
 const char *
 Parameter_getId (const Parameter_t *p)
@@ -1783,13 +1715,6 @@ Parameter_getId (const Parameter_t *p)
 }
 
 
-/**
- * Takes a Parameter_t structure and returns its name.
- *
- * @param p the Parameter_t whose name is sought.
- *
- * @return the name of this Parameter_t, as a pointer to a string.
- */
 LIBSBML_EXTERN
 const char *
 Parameter_getName (const Parameter_t *p)
@@ -1798,13 +1723,6 @@ Parameter_getName (const Parameter_t *p)
 }
 
 
-/**
- * Takes a Parameter_t structure and returns its value.
- *
- * @param p the Parameter_t whose value is sought.
- *
- * @return the value assigned to this Parameter_t structure, as a @c double.
- */
 LIBSBML_EXTERN
 double
 Parameter_getValue (const Parameter_t *p)
@@ -1813,14 +1731,6 @@ Parameter_getValue (const Parameter_t *p)
 }
 
 
-/**
- * Takes a Parameter_t structure and returns its units.
- *
- * @param p the Parameter_t whose units are sought.
- *
- * @return the units assigned to this Parameter_t structure, as a pointer
- * to a string.  
- */
 LIBSBML_EXTERN
 const char *
 Parameter_getUnits (const Parameter_t *p)
@@ -1829,15 +1739,6 @@ Parameter_getUnits (const Parameter_t *p)
 }
 
 
-/**
- * Takes a Parameter_t structure and returns zero or nonzero, depending
- * on the value of the parameter's "constant" attribute.
- *
- * @param p the Parameter_t whose constant value is sought.
- *
- * @return the value of the "constant" attribute, with nonzero meaning
- * true and zero meaning false.
- */
 LIBSBML_EXTERN
 int
 Parameter_getConstant (const Parameter_t *p)
@@ -1846,15 +1747,6 @@ Parameter_getConstant (const Parameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Parameter_t structure's identifier is set.
- *
- * @param p the Parameter_t structure to query
- * 
- * @return @c non-zero (true) if the "id" attribute of the given
- * Parameter_t structure is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 Parameter_isSetId (const Parameter_t *p)
@@ -1863,15 +1755,6 @@ Parameter_isSetId (const Parameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Parameter_t structure's name is set.
- *
- * @param p the Parameter_t structure to query
- * 
- * @return @c non-zero (true) if the "name" attribute of the given
- * Parameter_t structure is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 Parameter_isSetName (const Parameter_t *p)
@@ -1880,19 +1763,6 @@ Parameter_isSetName (const Parameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Parameter_t structure's value is set.
- * 
- * @param p the Parameter_t structure to query
- * 
- * @return @c non-zero (true) if the "value" attribute of the given
- * Parameter_t structure is set, zero (false) otherwise.
- *
- * @note In SBML Level 1 Version 1, a Parameter value is required and
- * therefore <em>should always be set</em>.  In Level 1 Version 2 and
- * later, the value is optional, and as such, may or may not be set.
- */
 LIBSBML_EXTERN
 int
 Parameter_isSetValue (const Parameter_t *p)
@@ -1901,15 +1771,6 @@ Parameter_isSetValue (const Parameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Parameter_t structure's units have been set.
- *
- * @param p the Parameter_t structure to query
- * 
- * @return @c non-zero (true) if the "units" attribute of the given
- * Parameter_t structure is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 Parameter_isSetUnits (const Parameter_t *p)
@@ -1918,15 +1779,6 @@ Parameter_isSetUnits (const Parameter_t *p)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Parameter_t structure's constant attribute have been set.
- *
- * @param p the Parameter_t structure to query
- * 
- * @return @c non-zero (true) if the "constant" attribute of the given
- * Parameter_t structure is set, zero (false) otherwise.
- */
 LIBSBML_EXTERN
 int
 Parameter_isSetConstant (const Parameter_t *p)
@@ -1935,24 +1787,6 @@ Parameter_isSetConstant (const Parameter_t *p)
 }
 
 
-/**
- * Assigns the identifier of a Parameter_t structure.
- *
- * This makes a copy of the string passed in the param @p sid.
- *
- * @param p the Parameter_t structure to set.
- * @param sid the string to use as the identifier.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with an id of NULL is equivalent to
- * unsetting the "id" attribute.
- */
 LIBSBML_EXTERN
 int
 Parameter_setId (Parameter_t *p, const char *sid)
@@ -1964,24 +1798,6 @@ Parameter_setId (Parameter_t *p, const char *sid)
 }
 
 
-/**
- * Assign the name of a Parameter_t structure.
- *
- * This makes a copy of the string passed in as the argument @p name.
- *
- * @param p the Parameter_t structure to set.
- * @param name the string to use as the name.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with the name set to NULL is equivalent to
- * unsetting the "name" attribute.
- */
 LIBSBML_EXTERN
 int
 Parameter_setName (Parameter_t *p, const char *name)
@@ -1993,18 +1809,6 @@ Parameter_setName (Parameter_t *p, const char *name)
 }
 
 
-/**
- * Assign the value of a Parameter_t structure.
- *
- * @param p the Parameter_t structure to set.
- * @param value the @c double value to use.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- */
 LIBSBML_EXTERN
 int
 Parameter_setValue (Parameter_t *p, double value)
@@ -2016,24 +1820,6 @@ Parameter_setValue (Parameter_t *p, double value)
 }
 
 
-/**
- * Assign the units of a Parameter_t structure.
- *
- * This makes a copy of the string passed in as the argument @p units.
- *
- * @param p the Parameter_t structure to set.
- * @param units the string to use as the identifier of the units to assign.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with units set to NULL is equivalent to
- * unsetting the "units" attribute.
- */
 LIBSBML_EXTERN
 int
 Parameter_setUnits (Parameter_t *p, const char *units)
@@ -2045,20 +1831,6 @@ Parameter_setUnits (Parameter_t *p, const char *units)
 }
 
 
-/**
- * Assign the "constant" attribute of a Parameter_t structure.
- *
- * @param p the Parameter_t structure to set.
- * @param value the value to assign as the "constant" attribute
- * of the parameter, either zero for false or nonzero for true.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_UNEXPECTED_ATTRIBUTE
- */
 LIBSBML_EXTERN
 int
 Parameter_setConstant (Parameter_t *p, int value)
@@ -2070,18 +1842,6 @@ Parameter_setConstant (Parameter_t *p, int value)
 }
 
 
-/**
- * Unsets the name of this Parameter_t structure.
- * 
- * @param p the Parameter_t structure whose name is to be unset.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Parameter_unsetName (Parameter_t *p)
@@ -2093,22 +1853,6 @@ Parameter_unsetName (Parameter_t *p)
 }
 
 
-/**
- * Unsets the value of this Parameter_t structure.
- *
- * In SBML Level 1 Version 1, a parameter is required to have a value and
- * therefore this attribute <em>should always be set</em>.  In Level 1
- * Version 2 and beyond, a value is optional, and as such, may or may not be
- * set.
- *
- * @param p the Parameter_t structure whose value is to be unset.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- */
 LIBSBML_EXTERN
 int
 Parameter_unsetValue (Parameter_t *p)
@@ -2120,18 +1864,6 @@ Parameter_unsetValue (Parameter_t *p)
 }
 
 
-/**
- * Unsets the units of this Parameter_t structure.
- * 
- * @param p the Parameter_t structure whose units are to be unset.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Parameter_unsetUnits (Parameter_t *p)
@@ -2143,19 +1875,6 @@ Parameter_unsetUnits (Parameter_t *p)
 }
 
 
-/**
- * Constructs and returns a UnitDefinition_t structure that expresses 
- * the units of this Parameter_t structure.
- *
- * @param p the Parameter_t structure whose units are to be returned.
- *
- * @return a UnitDefinition_t structure that expresses the units 
- * of this Parameter_t strucuture.
- *
- * @note This function returns the units of the Parameter_t expressed 
- * as a UnitDefinition_t. The units may be those explicitly declared. 
- * In the case where no units have been declared, @c NULL is returned.
- */
 LIBSBML_EXTERN
 UnitDefinition_t * 
 Parameter_getDerivedUnitDefinition(Parameter_t *p)
@@ -2164,20 +1883,6 @@ Parameter_getDerivedUnitDefinition(Parameter_t *p)
 }
 
 
-/**
-  * Predicate returning @c true or @c false depending on whether
-  * all the required attributes for this Parameter object
-  * have been set.
-  *
- * @param p the Parameter_t structure to check.
- *
-  * @note The required attributes for a Parameter object are:
-  * @li id (name in L1)
-  * @li constant (in L3 only)
-  *
-  * @return a true if all the required
-  * attributes for this object have been defined, false otherwise.
-  */
 LIBSBML_EXTERN
 int
 Parameter_hasRequiredAttributes(Parameter_t *p)
@@ -2186,10 +1891,6 @@ Parameter_hasRequiredAttributes(Parameter_t *p)
 }
 
 
-/**
- * @return item in this ListOfParameter with the given @p id or @c NULL if no such
- * item exists.
- */
 LIBSBML_EXTERN
 Parameter_t *
 ListOfParameters_getById (ListOf_t *lo, const char *sid)
@@ -2202,11 +1903,6 @@ ListOfParameters_getById (ListOf_t *lo, const char *sid)
 }
 
 
-/**
- * Removes item in this ListOf items with the given @p id or @c NULL if no such
- * item exists.  The caller owns the returned item and is responsible for
- * deleting it.
- */
 LIBSBML_EXTERN
 Parameter_t *
 ListOfParameters_removeById (ListOf_t *lo, const char *sid)
