@@ -8,9 +8,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -324,16 +329,15 @@ Rule::setFormula (const std::string& formula)
   }
   else 
   {
-    ASTNode * math = SBML_parseFormula(formula.c_str());
     if (formula == "")
     {
-      delete math;
       mFormula.erase();
       delete mMath;
       mMath = NULL;
       return LIBSBML_OPERATION_SUCCESS;
     }
-    else if (math == NULL || !(math->isWellFormedASTNode()))
+    ASTNode * math = SBML_parseFormula(formula.c_str());
+    if (math == NULL || !(math->isWellFormedASTNode()))
     {
       delete math;
       return LIBSBML_INVALID_OBJECT;
@@ -980,7 +984,23 @@ Rule::readOtherXML (XMLInputStream& stream)
       }
       else
       {
-        logError(OneMathElementPerRule, getLevel(), getVersion());
+        std::string details;
+        if (isAssignment() == true)
+        {
+          details = "The <assignmentRule> with variable '" + getVariable() +"'";
+        }
+        else if (isRate() == true)
+        {
+          details = "The <rateRule> with variable '" + getVariable() +"'";
+        }
+        else
+        {
+          details = "The <algebraicRule>";
+        }
+
+        details += " contains more than one <math> element.";
+
+        logError(OneMathElementPerRule, getLevel(), getVersion(), details);
       }
     }
     delete mMath;
@@ -1652,7 +1672,7 @@ ListOfRules::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
 LIBSBML_EXTERN
