@@ -9,9 +9,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -134,14 +139,6 @@ SBMLDocument::SBMLDocument (unsigned int level, unsigned int version) :
  , mRequiredAttrOfUnknownPkg()
  , mRequiredAttrOfUnknownDisabledPkg()
 {
-
-  mInternalValidator = new SBMLInternalValidator();
-  mInternalValidator->setDocument(this);
-  mInternalValidator->setApplicableValidators(AllChecksON);
-  mInternalValidator->setConversionValidators(AllChecksON);
-
-  mSBML = this;
-
   if (mLevel   == 0 && mVersion == 0)  
   {
     mLevel   = getDefaultLevel  ();
@@ -158,6 +155,13 @@ SBMLDocument::SBMLDocument (unsigned int level, unsigned int version) :
   if (!hasValidLevelVersionNamespaceCombination())
     throw SBMLConstructorException();
 
+  mInternalValidator = new SBMLInternalValidator();
+  mInternalValidator->setDocument(this);
+  mInternalValidator->setApplicableValidators(AllChecksON);
+  mInternalValidator->setConversionValidators(AllChecksON);
+
+  mSBML = this;
+
   setElementNamespace(mSBMLNamespaces->getURI());
 }
 
@@ -169,6 +173,10 @@ SBMLDocument::SBMLDocument (SBMLNamespaces* sbmlns) :
  , mRequiredAttrOfUnknownPkg()
  , mRequiredAttrOfUnknownDisabledPkg()
 {
+  if (!hasValidLevelVersionNamespaceCombination())
+  {
+    throw SBMLConstructorException(getElementName(), sbmlns);
+  }
 
   mInternalValidator = new SBMLInternalValidator();
   mInternalValidator->setDocument(this);
@@ -183,11 +191,6 @@ SBMLDocument::SBMLDocument (SBMLNamespaces* sbmlns) :
   // (TODO) Namespace check for extension packages 
   //        would need to be improved
   //
-  if (!hasValidLevelVersionNamespaceCombination())
-  {
-    throw SBMLConstructorException(getElementName(), sbmlns);
-  }
-
   //
   // (EXTENSION)
   //
@@ -259,11 +262,11 @@ SBMLDocument::SBMLDocument (const SBMLDocument& orig) :
   }
   else
   {
-    setSBMLDocument(this);
-
     mLevel                             = orig.mLevel;
     mVersion                           = orig.mVersion;
 
+    setSBMLDocument(this);
+
     mInternalValidator = new SBMLInternalValidator();
     mInternalValidator->setDocument(this);
     mInternalValidator->setApplicableValidators(orig.getApplicableValidators());
@@ -348,6 +351,13 @@ SBMLDocument::clone () const
 }
 
 
+bool 
+SBMLDocument::isSetModel() const
+{
+  return mModel != NULL;
+}
+
+
 /*
  * @return the Model contained in this SBMLDocument.
  */
@@ -492,7 +502,8 @@ bool
 SBMLDocument::setLevelAndVersion (unsigned int level, unsigned int version,
                                   bool strict, bool ignorePackages)
 {
-  ConversionProperties prop(new SBMLNamespaces(level, version));
+  SBMLNamespaces sbmlns(level, version);
+  ConversionProperties prop(&sbmlns);
   prop.addOption("strict", strict, "should validity be preserved");
   prop.addOption("setLevelAndVersion", true, "convert the document to the given level and version");
   prop.addOption("ignorePackages", ignorePackages);
@@ -908,6 +919,12 @@ SBMLDocument::getError (unsigned int n) const
   return mErrorLog.getError(n);
 }
 
+const SBMLError*
+SBMLDocument::getErrorWithSeverity(unsigned int n, unsigned int severity) const
+{
+  return mErrorLog.getErrorWithSeverity(n, severity);
+}
+
 
 /*
  * @return the number of errors encountered during the parse of this
@@ -941,6 +958,13 @@ SBMLDocument::printErrors (std::ostream& stream) const
   getErrorLog()->printErrors(stream);
 }
 
+void
+SBMLDocument::printErrors(std::ostream& stream, unsigned int severity) const
+{
+  getErrorLog()->printErrors(stream, severity);
+}
+
+
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -1036,6 +1060,13 @@ SBMLDocument::createObject (XMLInputStream& stream)
 
   if (name == "model")
   {
+    // check that we do not already have a model
+    if (isSetModel() == true)
+    {
+      logError(NotSchemaConformant, getLevel(), getVersion(), 
+        "Only one <model> element is allowed within an SBMLDocument.");
+    }
+
     delete mModel;
 
     try
@@ -1185,6 +1216,21 @@ SBMLDocument::setPackageRequired(const std::string& package, bool flag)
   return LIBSBML_PKG_UNKNOWN_VERSION;
 }
 
+
+/** @cond doxygenLibsbmlInternal */
+int
+SBMLDocument::addUnknownPackageRequired(const std::string& pkgURI,
+                                const std::string& prefix, bool flag)
+{
+  std::string value = (flag) ? "true" : "false";
+
+  mRequiredAttrOfUnknownPkg.add("required", value, pkgURI, prefix);
+
+  return LIBSBML_OPERATION_SUCCESS;
+}
+/** @endcond */
+
+
 int
 SBMLDocument::setPkgRequired(const std::string& package, bool flag)
 {
@@ -1294,6 +1340,20 @@ SBMLDocument::isDisabledIgnoredPackage(const std::string& pkgURI)
   return false;
 }
 
+
+/** @cond doxygenLibsbmlInternal */
+bool
+SBMLDocument::hasUnknownPackage(const std::string& pkgURI)
+{
+  // has this package been added to teh list of unknown required attributes
+  std::string req = mRequiredAttrOfUnknownPkg.getValue("required", pkgURI);
+  if (!req.empty()) return true;
+
+  return false;
+}
+/** @endcond */
+
+
 bool 
 SBMLDocument::isIgnoredPkg(const std::string& pkgURI)
 {
@@ -1846,7 +1906,7 @@ SBMLDocument::enablePackageInternal(const std::string& pkgURI, const std::string
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
 
@@ -1932,6 +1992,14 @@ SBMLDocument_getVersion (const SBMLDocument_t *d)
 }
 
 
+LIBSBML_EXTERN
+int
+SBMLDocument_isSetModel(const SBMLDocument_t *d)
+{
+  return (d != NULL) ? (int)d->isSetModel() : 0;
+}
+
+
 LIBSBML_EXTERN
 Model_t *
 SBMLDocument_getModel (SBMLDocument_t *d)
@@ -2101,6 +2169,14 @@ SBMLDocument_checkL2v4Compatibility (SBMLDocument_t *d)
 }
 
 
+LIBSBML_EXTERN
+unsigned int 
+SBMLDocument_checkL3v1Compatibility (SBMLDocument_t *d)
+{
+  return (d != NULL) ? d->checkL3v1Compatibility() : SBML_INT_MAX;
+}
+
+
 LIBSBML_EXTERN
 const SBMLError_t *
 SBMLDocument_getError (SBMLDocument_t *d, unsigned int n)
@@ -2108,6 +2184,13 @@ SBMLDocument_getError (SBMLDocument_t *d, unsigned int n)
   return (d != NULL) ? d->getError(n) : NULL;
 }
 
+LIBSBML_EXTERN
+const SBMLError_t *
+SBMLDocument_getErrorWithSeverity(SBMLDocument_t *d, unsigned int n, unsigned int severity)
+{
+  return (d != NULL) ? d->getErrorWithSeverity(n, severity) : NULL;
+}
+
 
 LIBSBML_EXTERN
 unsigned int
