@@ -93,6 +93,20 @@ SBMLTransforms::replaceFD(ASTNode * node, const FunctionDefinition *fd, const Id
   if ((node == NULL) || (fd == NULL))
     return;
   
+  recurseReplaceFD(node, fd, idsToExclude);
+
+#ifndef LIBSBML_USE_LEGACY_MATH
+  node->setIsChildFlag(false);
+#endif
+}
+
+
+void
+SBMLTransforms::recurseReplaceFD(ASTNode * node, const FunctionDefinition *fd, const IdList* idsToExclude /*= NULL*/)
+{
+  if ((node == NULL) || (fd == NULL))
+    return;
+
   if (node->isFunction()
     && node->getName() != NULL
       && node->getName() == fd->getId()
@@ -101,40 +115,44 @@ SBMLTransforms::replaceFD(ASTNode * node, const FunctionDefinition *fd, const Id
    replaceBvars(node, fd);
    for (unsigned int j = 0; j < node->getNumChildren(); j++)
    {
-     replaceFD(node->getChild(j), fd, idsToExclude);
+     recurseReplaceFD(node->getChild(j), fd, idsToExclude);
    }
   }
   else
   {
     for (unsigned int i = 0; i < node->getNumChildren(); i++)
     {
-      replaceFD(node->getChild(i), fd, idsToExclude);
+      recurseReplaceFD(node->getChild(i), fd, idsToExclude);
     }
   }
 }
+
+
 void
 SBMLTransforms::replaceBvars(ASTNode * node, const FunctionDefinition *fd)
 {
-  ASTNode * fdMath = NULL;
+  if (node==NULL) return;
+  if (fd==NULL) return;
+
+  ASTNode fdMath(AST_UNKNOWN);
   unsigned int noBvars;
 
-  if (fd != NULL && fd->isSetMath())
-    {
-      noBvars = fd->getMath()->getNumBvars();
-      fdMath = fd->getMath()->getRightChild()->deepCopy();
+  if (fd->isSetMath() && fd->getMath()->getRightChild() != NULL)
+  {
+    noBvars = fd->getMath()->getNumBvars();
+    fdMath = *fd->getMath()->getRightChild();
 
-      for (unsigned int i = 0, nodeCount = 0; i < noBvars; i++, nodeCount++)
+    for (unsigned int i = 0, nodeCount = 0; i < noBvars; i++, nodeCount++)
+    {
+      if (nodeCount < node->getNumChildren())
       {
-        if (nodeCount < node->getNumChildren())
-        {
-          fdMath->replaceArgument(fd->getArgument(i)->getName(), 
-                                            node->getChild(nodeCount));
-        }
+        fdMath.replaceArgument(fd->getArgument(i)->getName(), 
+          node->getChild(nodeCount));
       }
     }
+    (*node) = fdMath;
+  }
 
-  if (node !=NULL && fdMath != NULL)
-    (*node) = *fdMath;
 }
 
 
@@ -987,7 +1005,7 @@ SBMLTransforms::expandInitialAssignments(Model * m)
             if (expandInitialAssignment(m->getCompartment(id), 
                                         m->getInitialAssignment(i)))
             {
-              m->removeInitialAssignment(id);
+              delete m->removeInitialAssignment(id);
               count--;
             }
           }
@@ -996,7 +1014,7 @@ SBMLTransforms::expandInitialAssignments(Model * m)
             if (expandInitialAssignment(m->getParameter(id), 
                                         m->getInitialAssignment(i)))
             {
-              m->removeInitialAssignment(id);
+              delete m->removeInitialAssignment(id);
               count--;
             }
           }
@@ -1005,7 +1023,7 @@ SBMLTransforms::expandInitialAssignments(Model * m)
             if (expandInitialAssignment(m->getSpecies(id), 
                                         m->getInitialAssignment(i)))
             {
-              m->removeInitialAssignment(id);
+              delete m->removeInitialAssignment(id);
               count--;
             }
           }
@@ -1022,7 +1040,7 @@ SBMLTransforms::expandInitialAssignments(Model * m)
                   if (expandInitialAssignment(r->getProduct(k), 
                                               m->getInitialAssignment(i)))
                   {
-                    m->removeInitialAssignment(id);
+                    delete m->removeInitialAssignment(id);
                     count--;
                   }
                 }
@@ -1034,7 +1052,7 @@ SBMLTransforms::expandInitialAssignments(Model * m)
                   if (expandInitialAssignment(r->getReactant(k), 
                                               m->getInitialAssignment(i)))
                   {
-                    m->removeInitialAssignment(id);
+                    delete m->removeInitialAssignment(id);
                     count--;
                   }
                 }
