@@ -31,7 +31,7 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class SBMLWriter
- * @sbmlbrief{core} Methods for writing SBML to files and text strings.
+ * @sbmlbrief{core} File and text-string SBML writer.
  *
  * @htmlinclude not-sbml-warning.html
  *
@@ -41,18 +41,18 @@
  * for writing SBML all take an SBMLDocument object and a destination.  
  * They return a boolean or integer value to indicate success or failure.
  *
- * @section compression Support for writing compressed files
+ * @section sbmlwriter-compression Support for writing compressed files
  *
  * LibSBML provides support for writing (as well as reading) compressed
  * SBML files.  The process is transparent to the calling
- * application&mdash;the application does not need to do anything
+ * application---the application does not need to do anything
  * deliberate to invoke the functionality.  If a given SBML filename ends
  * with an extension for the @em gzip, @em zip or @em bzip2 compression
  * formats (respectively, <code>&quot;.gz&quot;</code>,
  * <code>&quot;.zip&quot;</code>, or <code>&quot;.bz2&quot;</code>),
  * then the methods
- * SBMLWriter::writeSBML(@if java SBMLDocument d, String filename@endif)
- * and SBMLReader::readSBML(@if java String filename@endif)
+ * SBMLWriter::writeSBML(@if java SBMLDocument, String@endif)
+ * and SBMLReader::readSBML(@if java String@endif)
  * will automatically compress and decompress the file while writing and
  * reading it.  If the filename has no such extension, it
  * will be written and read uncompressed as normal.
@@ -126,7 +126,7 @@ public:
    * write out the SBMLDocument.
    *
    * If the program name and version are set (see
-   * SBMLWriter::setProgramVersion(@if java String version@endif)), the
+   * SBMLWriter::setProgramVersion(@if java String@endif)), the
    * following XML comment, intended for human consumption, will be written
    * at the beginning of the XML document:
    * @verbatim
@@ -140,10 +140,8 @@ public:
    * @param name the name of this program (where "this program" refers to
    * program in which libSBML is embedded, not libSBML itself!)
    *
-   * @return integer value indicating success/failure of the
-   * function.  The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    * 
    * @see setProgramVersion(const std::string& version)
    */
@@ -155,7 +153,7 @@ public:
    * write out the SBMLDocument.
    *
    * If the program version and name are set (see
-   * SBMLWriter::setProgramName(@if java String name@endif)), the
+   * SBMLWriter::setProgramName(@if java String@endif)), the
    * following XML comment, intended for human consumption, will be written
    * at the beginning of the document:
    * @verbatim
@@ -169,10 +167,8 @@ public:
    * @param version the version of this program (where "this program"
    * refers to program in which libSBML is embedded, not libSBML itself!)
    *
-   * @return integer value indicating success/failure of the
-   * function.  The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    *
    * @see setProgramName(const std::string& name)
    */
@@ -275,6 +271,22 @@ public:
    */
   char* writeSBMLToString (const SBMLDocument* d);
 
+#ifndef SWIG
+  /**
+   * Writes the given SBML document to an in-memory string and returns it.
+   *
+   * @param d the SBML document to be written
+   *
+   * @return the string on success or an empty string, 
+   *         if one of the underlying parser
+   *         components fail.
+   * 
+   * @see setProgramVersion(const std::string& version)
+   * @see setProgramName(const std::string& name)
+   */
+  std::string writeSBMLToStdString(const SBMLDocument* d);
+#endif
+  
 
   /**
    * Predicate returning @c true if this copy of libSBML has been linked
@@ -323,6 +335,23 @@ public:
   /** @endcond */
 };
 
+#ifndef SWIG
+
+/**
+ * Writes the given SBML document to an in-memory string that is returned.
+ *
+ * @param d the SBML document to be written
+ *
+ * @return the string on success or an empty string, 
+ *         if one of the underlying parser
+ *         components fail.
+ * 
+ */
+LIBSBML_EXTERN
+std::string writeSBMLToStdString(const SBMLDocument* d);
+
+#endif
+
 LIBSBML_CPP_NAMESPACE_END
 
 #endif  /* __cplusplus */
@@ -362,11 +391,8 @@ SBMLWriter_free (SBMLWriter_t *sw);
  *   <!-- Created by <program name> version <program version>
  *   on yyyy-MM-dd HH:mm with libSBML version <libsbml version>. -->
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
  *
  * @memberof SBMLWriter_t
  */
@@ -383,11 +409,8 @@ SBMLWriter_setProgramName (SBMLWriter_t *sw, const char *name);
  *   <!-- Created by <program name> version <program version>
  *   on yyyy-MM-dd HH:mm with libSBML version <libsbml version>. -->
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
  *
  * @memberof SBMLWriter_t
  */
