@@ -534,7 +534,7 @@ Model* CompModelPlugin::flattenModel() const
       //Strip the ports from the submodel, as we no longer need them.
       while (submodplug->getNumPorts() > 0) 
       {
-        submodplug->removePort(0);
+        delete submodplug->removePort(0);
       }
     }
     success = flat->appendFrom(submodel);
@@ -644,8 +644,12 @@ CompModelPlugin::appendFrom(const Model* model)
   const CompModelPlugin* modplug = 
     static_cast<const CompModelPlugin*>(model->getPlugin(getPrefix()));
   
-  if (modplug==NULL) 
-    return LIBSBML_INVALID_OBJECT;
+  // absence of a plugin is not an error
+  if (modplug==NULL)
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+
 
   Model* parent = static_cast<Model*>(getParentSBMLObject());
 
@@ -693,14 +697,17 @@ CompModelPlugin::instantiateSubmodels()
       return LIBSBML_OPERATION_FAILED;
     }
     
-    // if we have a transformer specified, then we need to propagate it, so it can
-    // be used
-    if (isSetTransformer())
-    {
-      CompModelPlugin* other = dynamic_cast<CompModelPlugin*>(submodinst->getPlugin("comp"));
-      if (other != NULL)
-        other->setTransformer(getTransformer());
-    }
+    //// if we have a transformer specified, then we need to propagate it, so it can
+    //// be used
+
+    // this needs to happen in Submodel:instantiate
+
+    //if (isSetTransformer())
+    //{
+    //  CompModelPlugin* other = dynamic_cast<CompModelPlugin*>(submodinst->getPlugin("comp"));
+    //  if (other != NULL)
+    //    other->setTransformer(getTransformer());
+    //}
   }
 
   // Next, recursively find all the targets of SBaseRef elements 
@@ -775,6 +782,7 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
   if (model->isSetId()) {
     modname = "the model '" + model->getId() + "'";
   }
+  set<SBase*> todelete;
   for (unsigned int el=0; el<allElements->getSize(); el++) {
     SBase* element = static_cast<SBase*>(allElements->get(el));
     int type = element->getTypeCode();
@@ -808,8 +816,6 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
                      CompIdRefMayReferenceUnknownPackage, getPackageVersion(), 
                      getLevel(), getVersion(), fullmsg, element->getLine(), 
                      element->getColumn(), LIBSBML_SEV_WARNING);
-                    element->removeFromParentAndDelete();
-                    continue;
                 }
                 else if ( lasterr->getErrorId() == CompMetaIdRefMustReferenceObject)
                 {
@@ -823,27 +829,11 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
                      CompMetaIdRefMayReferenceUnknownPkg, getPackageVersion(), 
                      getLevel(), getVersion(), fullmsg, element->getLine(), 
                      element->getColumn(), LIBSBML_SEV_WARNING);
-                    element->removeFromParentAndDelete();
-                    continue;
-                }
-                else if (lasterr->getErrorId() == 
-                                  CompIdRefMayReferenceUnknownPackage)
-                {
-                  element->removeFromParentAndDelete();
-                  continue;
-                }
-                else if (lasterr->getErrorId() == 
-                                  CompMetaIdRefMayReferenceUnknownPkg)
-                {
-                  element->removeFromParentAndDelete();
-                  continue;
                 }
               }
-              else 
-              {
-                delete allElements;
-                return ret;
-              }
+              //Whether or not we could figure out the error, we can always still continue flattening.
+              todelete.insert(element);
+              continue;
             }
             else {
               delete allElements;
@@ -910,11 +900,14 @@ int CompModelPlugin::saveAllReferencedElements(set<SBase*> uniqueRefs, set<SBase
     }
   }
 
+  for(set<SBase*>::iterator el=todelete.begin(); el != todelete.end(); el++) {
+    (*el)->removeFromParentAndDelete();
+  }
   delete allElements;
 
   //Now call saveAllReferencedElements for all instantiated submodels.
-  for (unsigned long sm=0; sm<getNumSubmodels(); sm++) {
-    Model* sub = getSubmodel(sm)->getInstantiation();
+  for (unsigned long sm=0; sm<getNumSubmodels(); ++sm) {
+    Model* sub = getSubmodel((unsigned int)sm)->getInstantiation();
     if (sub==NULL) {
       return LIBSBML_OPERATION_FAILED;
     }
@@ -1030,8 +1023,8 @@ void CompModelPlugin::findUniqueSubmodPrefixes(vector<string>& submodids, List*
         fullprefix << suffixes[str];
       }
       fullprefix << getDivider();
-      for (unsigned long el=0; el<allElements->getSize(); el++) {
-        SBase* element = static_cast<SBase*>(allElements->get(el));
+      for (unsigned long el=0; el<allElements->getSize(); ++el) {
+        SBase* element = static_cast<SBase*>(allElements->get((unsigned int)el));
         if (element==NULL) {
           assert(false);
           continue;
@@ -1091,7 +1084,7 @@ void CompModelPlugin::renameIDs(List* allElements, const string& prefix)
   
   for (unsigned long el=0; el < allElements->getSize(); ++el) 
   {
-    SBase* element = static_cast<SBase*>(allElements->get(el));
+    SBase* element = static_cast<SBase*>(allElements->get((unsigned int)el));
     string id = element->getId();
     string metaid = element->getMetaId();
     
@@ -1128,7 +1121,7 @@ void CompModelPlugin::renameIDs(List* allElements, const string& prefix)
   }
 
   for (unsigned long el=0; el<allElements->getSize(); el++) {
-    SBase* element = static_cast<SBase*>(allElements->get(el));
+    SBase* element = static_cast<SBase*>(allElements->get((unsigned int)el));
     for (size_t id=0; id<renamedSIds.size(); id++) 
     {
       element->renameSIdRefs(renamedSIds[id].first, renamedSIds[id].second);
