@@ -1,3 +1,4 @@
+
 /**
  * @file    SBaseRef.cpp
  * @brief   Implementation of SBaseRef, the SBase-derived class of the comp package.
@@ -73,6 +74,25 @@ SBaseRef::SBaseRef(CompPkgNamespaces* compns)
 }
 
 
+/** @cond doxygenLibsbmlInternal */
+SBaseRef::SBaseRef(CompPkgNamespaces* compns, bool isDerived)
+  : CompBase(compns)
+  , mMetaIdRef("")
+  , mPortRef("")
+  , mIdRef("")
+  , mUnitRef("")
+  , mSBaseRef(NULL)
+  , mReferencedElement(NULL)
+  , mDirectReference(NULL)
+{
+  if (!isDerived)
+  {
+    loadPlugins(compns);
+  }
+}
+/** @endcond */
+
+
 SBaseRef::SBaseRef(const SBaseRef& source) 
   : CompBase (source)
 {
@@ -796,7 +816,9 @@ SBaseRef::getReferencedElementFrom(Model* model)
     if (referent == NULL && doc) {
       string error = "In SBaseRef::getReferencedElementFrom, unable to find referenced element: no such SId in the model: '" + getIdRef() + "'.";
       if (doc->getErrorLog()->contains(UnrequiredPackagePresent) 
-        || doc->getErrorLog()->contains(RequiredPackagePresent))
+        || doc->getErrorLog()->contains(RequiredPackagePresent)
+        || model->getSBMLDocument()->getErrorLog()->contains(UnrequiredPackagePresent)
+        || model->getSBMLDocument()->getErrorLog()->contains(RequiredPackagePresent))
       {
         doc->getErrorLog()->logPackageError("comp", 
           CompIdRefMayReferenceUnknownPackage, getPackageVersion(), 
@@ -822,7 +844,9 @@ SBaseRef::getReferencedElementFrom(Model* model)
     if (referent == NULL && doc) {
       string error = "In SBaseRef::getReferencedElementFrom, unable to find referenced element: no such metaid in the model: '" + getMetaIdRef() + "'.";
       if (doc->getErrorLog()->contains(UnrequiredPackagePresent) 
-        || doc->getErrorLog()->contains(RequiredPackagePresent))
+        || doc->getErrorLog()->contains(RequiredPackagePresent)
+        || model->getSBMLDocument()->getErrorLog()->contains(UnrequiredPackagePresent)
+        || model->getSBMLDocument()->getErrorLog()->contains(RequiredPackagePresent))
       {
         doc->getErrorLog()->logPackageError("comp", 
           CompIdRefMayReferenceUnknownPackage, getPackageVersion(), 
@@ -958,10 +982,10 @@ int SBaseRef::collectDeletions(set<SBase*>* removed, set<SBase*>* toremove)
   CompSBasePlugin* todplug = static_cast<CompSBasePlugin*>(todelete->getPlugin(getPrefix()));
   if (todplug != NULL) {
     for (unsigned long re=0; re<todplug->getNumReplacedElements(); re++) {
-      todplug->getReplacedElement((unsigned int)re)->collectDeletions(removed, toremove);
+      static_cast<SBaseRef*>(todplug->getReplacedElement((unsigned int)re))->collectDeletions(removed, toremove);
     }
     if (todplug->isSetReplacedBy()) {
-      todplug->getReplacedBy()->collectDeletions(removed, toremove);
+      static_cast<SBaseRef*>(todplug->getReplacedBy())->collectDeletions(removed, toremove);
     }
   }
   return LIBSBML_OPERATION_SUCCESS;
