@@ -34,11 +34,13 @@
 #include <sbml/conversion/SBMLConverterRegister.h>
 
 #include <sbml/common/sbmlfwd.h>
+#include <sbml/SBMLDocument.h>
 #include <sbml/extension/SBasePlugin.h>
 #include <sbml/extension/SBMLDocumentPlugin.h>
 #include <sbml/packages/comp/common/CompExtensionTypes.h>
 #include <sbml/SBMLWriter.h>
 #include <sbml/SBMLReader.h>
+#include <sbml/util/IdList.h>
 
 #ifdef __cplusplus
 
@@ -56,14 +58,16 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 
 void CompFlatteningConverter::init()
 {
-  SBMLConverterRegistry::getInstance().addConverter
-                                      (new CompFlatteningConverter());
+  //'addConverter' adds a clone, not the original.
+  CompFlatteningConverter cfc;
+  SBMLConverterRegistry::getInstance().addConverter(&cfc);
 }
 /** @endcond */
 
 
 CompFlatteningConverter::CompFlatteningConverter() 
   : SBMLConverter("SBML Comp Flattening Converter")
+  , mPkgsToStrip (NULL)
 {
   mDisabledPackages.clear();
 }
@@ -73,6 +77,7 @@ CompFlatteningConverter::CompFlatteningConverter
                          (const CompFlatteningConverter& orig) :
 SBMLConverter(orig)
   , mDisabledPackages(orig.mDisabledPackages)
+  , mPkgsToStrip (orig.mPkgsToStrip)
 {
 }
 
@@ -88,6 +93,12 @@ CompFlatteningConverter::clone() const
  */
 CompFlatteningConverter::~CompFlatteningConverter ()
 {
+  if (mPkgsToStrip != NULL)
+  {
+    mPkgsToStrip->clear();
+    delete mPkgsToStrip;
+    mPkgsToStrip = NULL;
+  }
 }
 
 
@@ -110,6 +121,8 @@ CompFlatteningConverter::getDefaultProperties() const
     "specify whether to abort if any unflattenable packages are encountered");
   prop.addOption("stripUnflattenablePackages", true, 
     "specify whether to strip any unflattenable packages ignored by 'abortIfUnflattenable'");
+  prop.addOption("stripPackages", "", 
+    "comma separated list of packages to be stripped before flattening is attempted");
   return prop;
 }
 
@@ -125,6 +138,169 @@ CompFlatteningConverter::matchesProperties
 
 int 
 CompFlatteningConverter::convert()
+{  
+   // need to keep track so we can delete it later;
+  int basePathResolverIndex = -1;
+
+  // need to set the base path if we have the option
+  if (getProperties() != NULL && getProperties()->hasOption("basePath"))
+  {
+    string basePath = getProperties()->getValue("basePath");
+    if(basePath != ".")
+    {
+      // temporarily add a new resolver with the new basePath
+      SBMLFileResolver basePathResolver;
+      basePathResolver.addAdditionalDir(basePath);
+      basePathResolverIndex = 
+                   SBMLResolverRegistry::getInstance().getNumResolvers();
+      SBMLResolverRegistry::getInstance().addResolver(&basePathResolver);    
+    }
+  }  
+
+  // remember number of registered callbacks
+
+  int numRegisteredCallbacks = Submodel::getNumProcessingCallbacks();
+
+  int result = performConversion();
+
+  if (basePathResolverIndex != -1)
+  {
+    // if we added a resolver remove it
+    SBMLResolverRegistry::getInstance().removeResolver(basePathResolverIndex);
+  }
+
+  // remove all registered callbacks
+  for (int index = Submodel::getNumProcessingCallbacks()-1; index >= numRegisteredCallbacks; --index)
+  {
+    Submodel::removeProcessingCallback(index);
+  }
+  
+  // clean up PkgsToStrip
+  if (mPkgsToStrip != NULL)
+  {
+    mPkgsToStrip->clear();
+    delete mPkgsToStrip;
+    mPkgsToStrip = NULL;
+  }
+
+
+  return result;
+
+}
+
+struct disable_info {
+  SBMLDocument * doc;
+  IdList strippedPkgs;
+  std::set<std::pair<std::string, std::string> > disabledPkgs;
+  bool stripUnflattenable;
+  bool abortForRequiredOnly;
+};
+
+// simple callback enabling packages on main doc
+int EnablePackageOnParentDocument(Model* m, SBMLErrorLog *, void* userdata)
+{
+  if (m == NULL) return LIBSBML_OPERATION_FAILED;
+
+  // pull information out of userdata
+  disable_info * info = static_cast<disable_info*>(userdata);
+  
+  SBMLDocument *mainDoc = static_cast<SBMLDocument*>(info->doc);
+  std::set<std::pair<std::string, std::string> > disabled = 
+    static_cast<std::set <std::pair <std::string, std::string> > >(info->disabledPkgs);
+
+
+  if (mainDoc == NULL) return LIBSBML_OPERATION_FAILED;
+
+  XMLNamespaces *mainNS = mainDoc->getSBMLNamespaces()->getNamespaces();
+
+  XMLNamespaces *ns = m->getSBMLNamespaces()->getNamespaces();
+  for (int i = 0; i < ns->getLength(); i++)
+  {
+    std::string nsURI = ns->getURI(i);
+    std::string prefix = ns->getPrefix(i);
+    if (prefix.empty() == true)
+    {
+      continue;
+    }
+    else if (mainNS->containsUri(nsURI) == false)
+    {
+      bool alreadyDisabled = false;
+      for (set<pair<string, string> >::iterator pkg = disabled.begin();
+           pkg != disabled.end(); pkg++)
+      {
+        if ((*pkg).first == nsURI)
+        {
+          alreadyDisabled = true;
+          break;
+        }
+      }
+      // just in case
+      if (m->getSBMLDocument() == NULL)
+      {
+        continue;
+      }
+      if (m->isPackageEnabled(prefix) == true)
+      {
+        mainNS->add(nsURI, prefix);
+        mainDoc->enablePackage(nsURI, prefix, true);
+        mainDoc->setPackageRequired(prefix, 
+          m->getSBMLDocument()->getPackageRequired(prefix));
+        
+
+        // we also need to make sure that if m was a modelDefinition
+        // that we enable the package on its parent model
+        Model * parent = dynamic_cast<Model*>(m->getAncestorOfType(SBML_MODEL));
+        if (parent != NULL)
+        {
+          parent->enablePackageInternal(nsURI, prefix, true);
+        }
+      }
+      else if (m->getSBMLDocument()->hasUnknownPackage(nsURI) == true)
+      {
+        // here we are dealing with an unknown package
+        // need to decide whether to add the ns or not
+        bool addNS = true;
+        // if it was listed to be stripped do not add
+        if (info->strippedPkgs.contains(prefix) == true) 
+        {
+          addNS = false;
+        }
+        // if it has already been disabled do not add
+        else if (alreadyDisabled == true) 
+        {
+          addNS = false;
+        }
+        // if it is an unflattenable package and flags dicatate do not add
+        else if (info->stripUnflattenable == true)
+        {
+          if (info->abortForRequiredOnly == false)
+          {
+            addNS = false;
+          }
+          else if (m->getSBMLDocument()->getPackageRequired(nsURI) == true)
+          {
+            addNS = false;
+          }
+        }
+
+        if (addNS == true)
+        {
+          // we have an unknown package so we cannot enable it
+          // but we do tell the parent doc about it
+          mainNS->add(nsURI, prefix);
+          mainDoc->addUnknownPackageRequired(nsURI, prefix,
+            m->getSBMLDocument()->getPackageRequired(nsURI));
+        }
+      }
+    }
+  }
+
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
+/** @cond doxygenLibsbmlInternal */
+int 
+CompFlatteningConverter::performConversion()
 {  
   int result = LIBSBML_OPERATION_FAILED;
 
@@ -148,7 +324,14 @@ CompFlatteningConverter::convert()
     return LIBSBML_OPERATION_SUCCESS;
   }
 
-  // look at the document and work out the status of any packages
+  // strip packages as instructed by user
+  int success = stripPackages();
+  if (success != LIBSBML_OPERATION_SUCCESS)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+
+  // look at the document and work out the status of any remaining packages
   mPackageValues.clear();
   analyseDocument();
 
@@ -160,23 +343,7 @@ CompFlatteningConverter::convert()
     return LIBSBML_OPERATION_FAILED;
   }
 
-  // need to keep track so we can delete it later;
-  int basePathResolverIndex = -1;
-
-  // need to set the base path if we have the option
-  if (getProperties() != NULL && getProperties()->hasOption("basePath"))
-  {
-    string basePath = getProperties()->getValue("basePath");
-    if(basePath != ".")
-    {
-      // temporarily add a new resolver with the new basePath
-      SBMLFileResolver basePathResolver;
-      basePathResolver.addAdditionalDir(basePath);
-      basePathResolverIndex = 
-                   SBMLResolverRegistry::getInstance().getNumResolvers();
-      SBMLResolverRegistry::getInstance().addResolver(&basePathResolver);    
-    }
-  }  
+ 
 
   /* strip any unflattenable packages before we run validation */
   if (getStripUnflattenablePackages() == true)
@@ -190,39 +357,10 @@ CompFlatteningConverter::convert()
 
   if (getPerformValidation() == true)
   {
-    unsigned char origValidators = mDocument->getApplicableValidators();
-    mDocument->setApplicableValidators(AllChecksON);
-    
-    // set the flag to ignore flattening when validating
-    bool originalOverrideFlag = plugin->getOverrideCompFlattening();
-    plugin->setOverrideCompFlattening(true);
-    
-    mDocument->checkConsistency();
-
-    unsigned int errors = mDocument->getErrorLog()
-                        ->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
-    
-    // take out the error about a requiredpackage
-    // if the user has specified to not abort for any packages
-    // NOTE: we cannot actually remove it since the flattening code
-    // uses it to check whether references might come from
-    // other packages
-    if (getAbortForNone() == true)
+    int result = validateOriginalDocument();
+    if (result != LIBSBML_OPERATION_SUCCESS) 
     {
-      if (mDocument->getErrorLog()->contains(RequiredPackagePresent))
-      {
-        errors--;
-      }
-    }
-
-    // reset comp flattening flag and any validator
-    plugin->setOverrideCompFlattening(originalOverrideFlag);
-    mDocument->setApplicableValidators(origValidators);
-
-    if (errors > 0)
-    {
-      restoreNamespaces();
-      return LIBSBML_CONV_INVALID_SRC_DOCUMENT;
+      return result;
     }
   }
   CompModelPlugin *modelPlugin = (CompModelPlugin*)(mModel->getPlugin("comp"));
@@ -238,13 +376,17 @@ CompFlatteningConverter::convert()
     mDocument->getVersion(),
     "The subsequent errors are from this attempt.");
 
+  // setup callback that will enable the packages on submodels
+  disable_info mainDoc;
+  mainDoc.doc = mDocument;
+  mainDoc.strippedPkgs = getPackagesToStrip();
+  mainDoc.disabledPkgs = mDisabledPackages;
+  mainDoc.stripUnflattenable = getStripUnflattenablePackages();
+  mainDoc.abortForRequiredOnly = getAbortForRequired(); 
+ 
+  Submodel::addProcessingCallback(&EnablePackageOnParentDocument, &(mainDoc));
   Model* flatmodel = modelPlugin->flattenModel();
   
-  if (basePathResolverIndex != -1)
-  {
-    // if we added a resolver remove it
-    SBMLResolverRegistry::getInstance().removeResolver(basePathResolverIndex);
-  }
 
   if (flatmodel == NULL) 
   {
@@ -259,105 +401,14 @@ CompFlatteningConverter::convert()
 
   if (getPerformValidation() == true)
   {
-    // Otherwise, transfer only errors 1090107->1090110
-    SBMLErrorLog* log = mDocument->getErrorLog();
-    SBMLDocument *dummy = new SBMLDocument(mDocument->getSBMLNamespaces());
-    for (unsigned int en=0; en<log->getNumErrors(); en++) 
-    {
-      unsigned int errid = mDocument->getError(en)->getErrorId();
-      if (errid == CompFlatteningNotRecognisedNotReqd ||
-          errid == CompFlatteningNotRecognisedReqd ||
-          errid == CompFlatteningNotImplementedNotReqd ||
-          errid == CompFlatteningNotImplementedReqd)
-      {
-            dummy->getErrorLog()->add(*(mDocument->getError(en)));
-      }
-    }
-
-    log->clearLog();
-  
-    // create a dummyDocument that will mirror what the user options are 
-    //Now check to see if the flat model is valid
-    // run regular validation on the flattened document if requested.
-    result = reconstructDocument(flatmodel, *(dummy), true );
+    int result = validateFlatDocument(flatmodel, 
+                    modelPlugin->getPackageVersion(), modelPlugin->getLevel(), 
+                    modelPlugin->getVersion());
     if (result != LIBSBML_OPERATION_SUCCESS)
     {
       delete flatmodel;
-      restoreNamespaces();
       return result;
     }
-
-    // override comp flattening if necessary
-    CompSBMLDocumentPlugin * dummyPlugin = static_cast<CompSBMLDocumentPlugin*>
-                                           (dummy->getPlugin("comp"));
-
-    if (dummyPlugin != NULL)
-    {
-      dummyPlugin->setOverrideCompFlattening(true);
-    }
-
-    dummy->checkConsistency();
-
-    if (dummyPlugin != NULL)
-    {
-      dummyPlugin->setOverrideCompFlattening(false);
-    }
-
-    unsigned int errors = 
-             dummy->getErrorLog()->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
-    if (errors > 0)
-    {
-      // we have serious errors so we are going to bail on the
-      // flattening - log ONLY the errors
-      //Transfer the errors to mDocument and don't reset the model.
-      if (log->contains(CompLineNumbersUnreliable) == false)
-      {
-        log->logPackageError("comp", CompLineNumbersUnreliable, 
-          modelPlugin->getPackageVersion(), modelPlugin->getLevel(), 
-          modelPlugin->getVersion());
-      }
-      std::string message = "Errors that follow relate to the flattened ";
-      message += "document produced using the CompFlatteningConverter.";
-      log->logPackageError("comp", CompFlatModelNotValid,
-        modelPlugin->getPackageVersion(), modelPlugin->getLevel(), 
-        modelPlugin->getVersion(), message);
-    
-      unsigned int nerrors = dummy->getErrorLog()->getNumErrors();
-      for (unsigned int n = 0; n < nerrors; n++)
-      {
-        const SBMLError* error = dummy->getError(n);
-        if (error->getSeverity() >= LIBSBML_SEV_ERROR) 
-        {
-          log->add( *(error) );
-        }
-        if (error->getErrorId() >= CompFlatteningNotRecognisedNotReqd &&
-          error->getErrorId() <= CompFlatteningNotImplementedReqd) 
-        {
-          log->add( *(error) );
-        }
-        else if (error->getErrorId() == UnrequiredPackagePresent ||
-          error->getErrorId() == RequiredPackagePresent)
-        {
-          log->add( *(error) );
-        }
-      }
-      delete dummy;
-      delete flatmodel;
-      restoreNamespaces();
-      return LIBSBML_CONV_INVALID_SRC_DOCUMENT;
-    }
-    else
-    {
-      // put any warnings into the document that will be have the
-      // flat model
-      unsigned int nerrors = dummy->getErrorLog()->getNumErrors();
-      for (unsigned int n = 0; n < nerrors; n++)
-      {
-        const SBMLError* error = dummy->getError(n);
-        log->add( *(error) );
-      }
-      delete dummy;
-    }
   }
 
   // now reconstruct the document to be returned 
@@ -374,16 +425,18 @@ CompFlatteningConverter::convert()
   delete flatmodel;
   return LIBSBML_OPERATION_SUCCESS;
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 int
 CompFlatteningConverter::reconstructDocument(Model * flatmodel)
 {
-  SBMLDocument * tempDoc = NULL;
-  return reconstructDocument(flatmodel, *(tempDoc));
+  SBMLDocument tempDoc;
+  return reconstructDocument(flatmodel, tempDoc);
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 int
 CompFlatteningConverter::reconstructDocument(Model * flatmodel, 
                            SBMLDocument& dummyDoc,  bool dummyRecon)
@@ -397,16 +450,19 @@ CompFlatteningConverter::reconstructDocument(Model * flatmodel,
   }
 
   // now reconstruct the document taking user options into account
+  CompSBMLDocumentPlugin *docPlug = NULL;
   if (getLeavePorts() == true)
   {
     if (getLeaveDefinitions() == false)
     {
       int i;
-      CompSBMLDocumentPlugin *docPlug = NULL;
       if (dummyRecon == true)
       {
         docPlug = static_cast<CompSBMLDocumentPlugin *>
                               (dummyDoc.getPlugin("comp"));
+      // need to make sure comp required attribute is set
+      // or validation of dummyDoc will fail
+        docPlug->setRequired(true);
       }
       else
       {
@@ -416,16 +472,21 @@ CompFlatteningConverter::reconstructDocument(Model * flatmodel,
 
       for (i = docPlug->getNumModelDefinitions() - 1; i >= 0; i--)
       {
-        docPlug->removeModelDefinition(i);
+        delete docPlug->removeModelDefinition(i);
       }
       for (i = docPlug->getNumExternalModelDefinitions() - 1; i >= 0; i--)
       {
-        docPlug->removeExternalModelDefinition(i);
+        delete docPlug->removeExternalModelDefinition(i);
       }
 
     }
     if (dummyRecon == true)
     {
+      // need to make sure comp required attribute is set
+      // or validation of dummyDoc will fail
+      docPlug = static_cast<CompSBMLDocumentPlugin *>
+                            (dummyDoc.getPlugin("comp"));
+      docPlug->setRequired(true);
       result = dummyDoc.setModel(flatmodel);
     }
     else
@@ -456,6 +517,11 @@ CompFlatteningConverter::reconstructDocument(Model * flatmodel,
         result = dummyDoc.setModel(flatmodel);
         dummyDoc.enablePackage
                    (CompExtension::getXmlnsL3V1V1(), "comp", true);
+      // need to make sure comp required attribute is set
+      // or validation of dummyDoc will fail
+        docPlug = static_cast<CompSBMLDocumentPlugin *>
+                              (dummyDoc.getPlugin("comp"));
+        docPlug->setRequired(true);
      }
       else
       {
@@ -468,7 +534,245 @@ CompFlatteningConverter::reconstructDocument(Model * flatmodel,
 
   return result;
 }
+/** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
+int
+CompFlatteningConverter::validateOriginalDocument()
+{
+  CompSBMLDocumentPlugin *plugin = 
+                  (CompSBMLDocumentPlugin*)(mDocument->getPlugin("comp"));
+
+  unsigned char origValidators = mDocument->getApplicableValidators();
+  mDocument->setApplicableValidators(AllChecksON);
+  
+  // set the flag to ignore flattening when validating
+  bool originalOverrideFlag = plugin->getOverrideCompFlattening();
+  plugin->setOverrideCompFlattening(true);
+  
+  // force a read
+  std::string sbml = writeSBMLToStdString(mDocument);
+  SBMLDocument *tempdoc = readSBMLFromString(sbml.c_str());
+  for (unsigned int i = 0; i < tempdoc->getErrorLog()->getNumErrors(); i++)
+  {
+    // do not add the requried package present error
+    const SBMLError * error = tempdoc->getErrorLog()->getError(i);
+    if (error->getErrorId() != RequiredPackagePresent)
+    {
+      mDocument->getErrorLog()->add(*(error));
+    }
+  }
+  delete tempdoc;
+
+  mDocument->checkConsistency();
+
+  unsigned int errors = mDocument->getErrorLog()
+                      ->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
+  
+  // take out the error about a requiredpackage
+  // if the user has specified to not abort for any packages
+  // NOTE: we cannot actually remove it since the flattening code
+  // uses it to check whether references might come from
+  // other packages
+  if (getAbortForNone() == true)
+  {
+    if (mDocument->getErrorLog()->contains(RequiredPackagePresent))
+    {
+      errors--;
+    }
+  }
+
+  // reset comp flattening flag and any validator
+  plugin->setOverrideCompFlattening(originalOverrideFlag);
+  mDocument->setApplicableValidators(origValidators);
+
+  if (errors > 0)
+  {
+    restoreNamespaces();
+    return LIBSBML_CONV_INVALID_SRC_DOCUMENT;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+int
+CompFlatteningConverter::validateFlatDocument(Model * flatmodel,
+            unsigned int pkgVersion, unsigned int level, unsigned int version)
+{
+  int result;
+  // create a dummyDocument that will mirror what the user options are 
+   // we need the dummyDoc to know things about unknown packages
+  // but dont want teh original model/error log
+  SBMLDocument dummy = SBMLDocument(*(mDocument));
+  dummy.setModel(NULL);
+  dummy.getErrorLog()->clearLog();
+   
+  // Otherwise, transfer only errors 1090107->1090110
+  SBMLErrorLog* log = mDocument->getErrorLog();
+  for (unsigned int en=0; en<log->getNumErrors(); en++) 
+  {
+    unsigned int errid = mDocument->getError(en)->getErrorId();
+    if (errid == CompFlatteningNotRecognisedNotReqd ||
+        errid == CompFlatteningNotRecognisedReqd ||
+        errid == CompFlatteningNotImplementedNotReqd ||
+        errid == CompFlatteningNotImplementedReqd)
+    {
+          dummy.getErrorLog()->add(*(mDocument->getError(en)));
+    }
+  }
+
+  log->clearLog();
+
+  result = reconstructDocument(flatmodel, dummy, true );
+  if (result != LIBSBML_OPERATION_SUCCESS)
+  {
+    //delete flatmodel;
+    restoreNamespaces();
+    return result;
+  }
+
+ //Now check to see if the flat model is valid
+  // run regular validation on the flattened document if requested.
+
+  // override comp flattening if necessary
+  CompSBMLDocumentPlugin * dummyPlugin = static_cast<CompSBMLDocumentPlugin*>
+                                         (dummy.getPlugin("comp"));
+
+  if (dummyPlugin != NULL)
+  {
+    dummyPlugin->setOverrideCompFlattening(true);
+  }
+
+  std::string sbml = writeSBMLToStdString(&dummy);
+  SBMLDocument *tempdoc = readSBMLFromString(sbml.c_str());
+  unsigned int errors = 
+           tempdoc->getErrorLog()->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
+  
+  // take out the error about a requiredpackage
+  // if the user has specified to not abort for any packages
+  // NOTE: we cannot actually remove it since the flattening code
+  // uses it to check whether references might come from
+  // other packages
+  if (getAbortForNone() == true)
+  {
+    if (tempdoc->getErrorLog()->contains(RequiredPackagePresent))
+    {
+      errors--;
+    }
+  }
+
+  if (errors > 0)
+  {
+    // we have serious errors so we are going to bail on the
+    // flattening - log ONLY the errors
+    //Transfer the errors to mDocument and don't reset the model.
+    if (log->contains(CompLineNumbersUnreliable) == false)
+    {
+      log->logPackageError("comp", CompLineNumbersUnreliable, 
+        pkgVersion, level, version);
+    }
+    std::string message = "Errors that follow relate to the flattened ";
+    message += "document produced using the CompFlatteningConverter.";
+    log->logPackageError("comp", CompFlatModelNotValid,
+        pkgVersion, level, version);
+  
+    unsigned int nerrors = tempdoc->getErrorLog()->getNumErrors();
+    for (unsigned int n = 0; n < nerrors; n++)
+    {
+      const SBMLError* error = tempdoc->getError(n);
+      if (error->getSeverity() >= LIBSBML_SEV_ERROR) 
+      {
+        log->add( *(error) );
+      }
+      if (error->getErrorId() >= CompFlatteningNotRecognisedNotReqd &&
+        error->getErrorId() <= CompFlatteningNotImplementedReqd) 
+      {
+        log->add( *(error) );
+      }
+      else if (error->getErrorId() == UnrequiredPackagePresent ||
+        error->getErrorId() == RequiredPackagePresent)
+      {
+        log->add( *(error) );
+      }
+    }
+    //delete flatmodel;
+    restoreNamespaces();
+    delete tempdoc;
+    return LIBSBML_CONV_INVALID_SRC_DOCUMENT;
+  }
+  else
+  {
+    delete tempdoc;
+  }
+
+  dummy.checkConsistency();
+
+  if (dummyPlugin != NULL)
+  {
+    dummyPlugin->setOverrideCompFlattening(false);
+  }
+
+  errors = dummy.getErrorLog()->getNumFailsWithSeverity(LIBSBML_SEV_ERROR);
+  if (errors > 0)
+  {
+    // we have serious errors so we are going to bail on the
+    // flattening - log ONLY the errors
+    //Transfer the errors to mDocument and don't reset the model.
+    if (log->contains(CompLineNumbersUnreliable) == false)
+    {
+      log->logPackageError("comp", CompLineNumbersUnreliable, 
+        pkgVersion, level, version);
+    }
+    std::string message = "Errors that follow relate to the flattened ";
+    message += "document produced using the CompFlatteningConverter.";
+    log->logPackageError("comp", CompFlatModelNotValid,
+        pkgVersion, level, version);
+  
+    unsigned int nerrors = dummy.getErrorLog()->getNumErrors();
+    for (unsigned int n = 0; n < nerrors; n++)
+    {
+      const SBMLError* error = dummy.getError(n);
+      if (error->getSeverity() >= LIBSBML_SEV_ERROR) 
+      {
+        log->add( *(error) );
+      }
+      if (error->getErrorId() >= CompFlatteningNotRecognisedNotReqd &&
+        error->getErrorId() <= CompFlatteningNotImplementedReqd) 
+      {
+        log->add( *(error) );
+      }
+      else if (error->getErrorId() == UnrequiredPackagePresent ||
+        error->getErrorId() == RequiredPackagePresent)
+      {
+        log->add( *(error) );
+      }
+    }
+    //delete flatmodel;
+    restoreNamespaces();
+    return LIBSBML_CONV_INVALID_SRC_DOCUMENT;
+  }
+  else
+  {
+    // put any warnings into the document that will be have the
+    // flat model
+    unsigned int nerrors = dummy.getErrorLog()->getNumErrors();
+    for (unsigned int n = 0; n < nerrors; n++)
+    {
+      const SBMLError* error = dummy.getError(n);
+      log->add( *(error) );
+    }
+
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getLeavePorts() const
 {
@@ -485,7 +789,9 @@ CompFlatteningConverter::getLeavePorts() const
     return getProperties()->getBoolValue("leavePorts");
   }
 }
+/** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getLeaveDefinitions() const
 {
@@ -502,8 +808,9 @@ CompFlatteningConverter::getLeaveDefinitions() const
     return getProperties()->getBoolValue("listModelDefinitions");
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getIgnorePackages() const
 {
@@ -520,8 +827,9 @@ CompFlatteningConverter::getIgnorePackages() const
     return getProperties()->getBoolValue("ignorePackages");
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getStripUnflattenablePackages() const
 {
@@ -545,8 +853,9 @@ CompFlatteningConverter::getStripUnflattenablePackages() const
     return getProperties()->getBoolValue("stripUnflattenablePackages");
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getPerformValidation() const
 {
@@ -563,8 +872,9 @@ CompFlatteningConverter::getPerformValidation() const
     return getProperties()->getBoolValue("performValidation");
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getAbortForAll() const
 {
@@ -588,8 +898,9 @@ CompFlatteningConverter::getAbortForAll() const
     }
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getAbortForRequired() const
 {
@@ -613,8 +924,9 @@ CompFlatteningConverter::getAbortForRequired() const
     }
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::getAbortForNone() const
 {
@@ -638,8 +950,31 @@ CompFlatteningConverter::getAbortForNone() const
     }
   }
 }
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+const std::string& 
+CompFlatteningConverter::getPackagesToStrip() const
+{
+	static std::string empty = "";
+
+  if (getProperties() == NULL)
+  {
+    return empty;
+  }
+  else if (getProperties()->hasOption("stripPackages") == false)
+  {
+    return empty;
+  }
+  else
+  {
+    return getProperties()->getValue("stripPackages");
+  }
+}
+/** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 void
 CompFlatteningConverter::stripUnflattenablePackages()
 {
@@ -723,7 +1058,86 @@ CompFlatteningConverter::stripUnflattenablePackages()
 
   }
 }
+/** @endcond */
 
+// simple callback disabling packages on child documents
+int DisablePackageOnChildDocuments(Model* m, SBMLErrorLog *, void* userdata)
+{
+  if (m == NULL) return LIBSBML_OPERATION_FAILED;
+
+  IdList *pkgsToStrip = static_cast<IdList*>(userdata);
+
+  XMLNamespaces *ns = m->getSBMLNamespaces()->getNamespaces();
+  for (int i = 0; i < ns->getLength(); i++)
+  {
+    std::string nsURI = ns->getURI(i);
+    std::string package = ns->getPrefix(i);
+    if (package.empty() == true)
+    {
+      continue;
+    }
+    else if (pkgsToStrip->contains(package) == true)
+    {
+      m->enablePackageInternal(nsURI, package, false);
+    }
+  }
+
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
+/** @cond doxygenLibsbmlInternal */
+int
+CompFlatteningConverter::stripPackages()
+{
+  mPkgsToStrip = new IdList(getPackagesToStrip());
+
+  unsigned int num = mPkgsToStrip->size();
+
+  if (num == 0)
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+
+  XMLNamespaces *ns = mDocument->getSBMLNamespaces()->getNamespaces();
+  for (int i = 0; i < ns->getLength(); i++)
+  {
+    std::string nsURI = ns->getURI(i);
+    std::string package = ns->getPrefix(i);
+    if (package.empty() == true)
+    {
+      continue;
+    }
+    else if (mPkgsToStrip->contains(package) == true)
+    {
+      mDocument->enablePackage(nsURI, package, false);
+      mDisabledPackages.insert(make_pair(nsURI, package));
+    }
+  }
+
+  unsigned int count = 0;
+  for (unsigned int i = 0; i < num; i++)
+  {
+    if (mDocument->isPackageEnabled(mPkgsToStrip->at(i)) == false)
+    {
+      count++;
+    }
+  }
+
+  // setup callback that will disable the packages on submodels
+  Submodel::addProcessingCallback(&DisablePackageOnChildDocuments, mPkgsToStrip);
+
+  if (num == count)
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+}
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
 bool
 CompFlatteningConverter::canBeFlattened()
 {
@@ -799,8 +1213,9 @@ CompFlatteningConverter::canBeFlattened()
 
   return canFlatten;
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 void 
 CompFlatteningConverter::restoreNamespaces()
 {
@@ -810,8 +1225,9 @@ CompFlatteningConverter::restoreNamespaces()
     mDocument->enablePackage((*pkg).first, (*pkg).second, true);
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 void 
 CompFlatteningConverter::analyseDocument()
 {
@@ -876,8 +1292,10 @@ CompFlatteningConverter::analyseDocument()
     mPackageValues.insert(pair<const std::string, ValueSet>(package, values));
   }
 }
+/** @endcond */
 
  
+/** @cond doxygenLibsbmlInternal */
 bool 
 CompFlatteningConverter::getRequiredStatus(const std::string & package)
 {
@@ -887,8 +1305,10 @@ CompFlatteningConverter::getRequiredStatus(const std::string & package)
 
   return required;
 }
+/** @endcond */
 
   
+/** @cond doxygenLibsbmlInternal */
 bool 
 CompFlatteningConverter::getKnownStatus(const std::string& package)
 {
@@ -898,8 +1318,10 @@ CompFlatteningConverter::getKnownStatus(const std::string& package)
   
   return known;
 }
+/** @endcond */
 
   
+/** @cond doxygenLibsbmlInternal */
 bool 
 CompFlatteningConverter::getFlattenableStatus(const std::string& package)
 {
@@ -909,8 +1331,9 @@ CompFlatteningConverter::getFlattenableStatus(const std::string& package)
 
   return flattenable;
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool 
 CompFlatteningConverter::haveUnknownRequiredPackages()
 {
@@ -929,8 +1352,9 @@ CompFlatteningConverter::haveUnknownRequiredPackages()
 
   return haveUnknownReqd;
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool 
 CompFlatteningConverter::haveUnknownUnrequiredPackages()
 {
@@ -949,8 +1373,9 @@ CompFlatteningConverter::haveUnknownUnrequiredPackages()
 
   return haveUnknownUnreqd;
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool 
 CompFlatteningConverter::haveUnflattenableRequiredPackages()
 {
@@ -969,8 +1394,9 @@ CompFlatteningConverter::haveUnflattenableRequiredPackages()
 
   return haveUnflatReqd;
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 bool 
 CompFlatteningConverter::haveUnflattenableUnrequiredPackages()
 {
@@ -989,8 +1415,7 @@ CompFlatteningConverter::haveUnflattenableUnrequiredPackages()
 
   return haveUnflatUnreqd;
 }
-
-
+/** @endcond */
 
 
 
