@@ -172,7 +172,7 @@ DistribInput::getName() const
 /*
  * Returns the value of the "index" attribute of this DistribInput.
  */
-const unsigned int
+unsigned int
 DistribInput::getIndex() const
 {
   return mIndex;
@@ -462,7 +462,7 @@ DistribInput::enablePackageInternal(const std::string& pkgURI,
 SBase*
 DistribInput::createObject(XMLInputStream& stream)
 {
-  const string& name = stream.peek().getName();
+  //const string& name = stream.peek().getName();
   SBase* object = NULL;
 
   DISTRIB_CREATE_NS(distribns, getSBMLNamespaces());
@@ -738,6 +738,41 @@ ListOfDistribInputs::get(const std::string& sid) const
 }
 
 
+/*
+ * Get a DistribInput from the ListOfDistribInputs by id.
+ */
+DistribInput*
+ListOfDistribInputs::getByIndex(unsigned int n)
+{
+  return const_cast<DistribInput*>(
+    static_cast<const ListOfDistribInputs&>(*this).getByIndex(n));
+}
+
+
+#ifndef SWIG
+template<class CNAME>
+struct IndexEq : public std::unary_function<SBase*, bool>
+{
+  unsigned int n;
+
+  IndexEq (unsigned int n) : n(n) { }
+  bool operator() (SBase* sb) 
+       { return static_cast <CNAME*> (sb)->getIndex() == n; }
+};
+#endif /* SWIG */
+/*
+ * Get a DistribInput from the ListOfDistribInputs by id.
+ */
+const DistribInput*
+ListOfDistribInputs::getByIndex(unsigned int n) const
+{
+  vector<SBase*>::const_iterator result;
+
+  result = find_if( mItems.begin(), mItems.end(), IndexEq<DistribInput>(n) );
+  return (result == mItems.end()) ? 0 : static_cast <DistribInput*> (*result);
+}
+
+
 /*
  * Removes the nth DistribInput from this ListOfDistribInputs
  */
