@@ -42,19 +42,22 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  */
 UncertMLNode::UncertMLNode ()
   : mElementName ("")
+  , mText ("")
+  , mAttributes()
+  , mChildren()
 {
-  mChildren = new List();
 }
 
 /*
  * Creates a new UncertMLNode from XMLNode object.
  */
 UncertMLNode::UncertMLNode (XMLNode* xml)
-  : mElementName ("")
-  //, mAttributes ( NULL )
+  : mElementName ("")  
+  , mText ("")
+  , mAttributes()
+  , mChildren()
 {
-  mChildren = new List();
-  
+ 
   this->parseXMLNode(xml);
 }
 
@@ -70,11 +73,10 @@ UncertMLNode::UncertMLNode (const UncertMLNode& orig)
   }
   else
   {
-    mElementName  = orig.mElementName;
+    mElementName = orig.mElementName;
+    mText        = orig.mText;
     mAttributes  = orig.mAttributes;
 
-    mChildren = new List();
-
     for (unsigned int c = 0; c < orig.getNumChildren(); ++c)
     {
       addChild( orig.getChild(c)->clone() );
@@ -95,13 +97,17 @@ UncertMLNode::operator=(const UncertMLNode& rhs)
   }
   else if (&rhs != this)
   {
-    mElementName  = rhs.mElementName;
+    mElementName = rhs.mElementName;
+    mText        = rhs.mText;
     mAttributes  = rhs.mAttributes;
     
-    unsigned int size = mChildren->getSize();
-    while (size--) delete static_cast<UncertMLNode*>( mChildren->remove(0) );
-    delete mChildren;
-    mChildren = new List();
+    int size = (int)mChildren.size();
+    for (int i = size -1; i >=0;--i)
+    {
+      delete mChildren[i];
+    }
+
+    mChildren.clear();
 
     for (unsigned int c = 0; c < rhs.getNumChildren(); ++c)
     {
@@ -127,7 +133,14 @@ UncertMLNode::clone () const
  * Destructor for UncertMLNode.
  */
 UncertMLNode::~UncertMLNode ()
-{
+{  
+  int size = (int)mChildren.size();
+  for (int i = size -1; i >=0;--i)
+  {
+    delete mChildren[i];
+  }
+
+  mChildren.clear();
 }
 
 
@@ -141,6 +154,16 @@ UncertMLNode::getElementName() const
 }
 
 
+/*
+ * Returns the value of the "text" element of this UncertMLNode.
+ */
+const std::string&
+UncertMLNode::getText() const
+{
+  return mText;
+}
+
+
 /*
  * Returns the value of the "attributes" attribute of this UncertMLNode.
  */
@@ -161,6 +184,16 @@ UncertMLNode::isSetElementName() const
 }
 
 
+/*
+ * Returns true/false if text is set.
+ */
+bool
+UncertMLNode::isSetText() const
+{
+  return (mText.empty() == false);
+}
+
+
 /*
  * Returns true/false if attributes is set.
  */
@@ -189,6 +222,24 @@ UncertMLNode::setElementName(const std::string& elementName)
 }
 
 
+/*
+ * Sets text and returns value indicating success.
+ */
+int
+UncertMLNode::setText(const std::string& text)
+{
+  if (&(text) == NULL)
+  {
+    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  }
+  else
+  {
+    mText = text;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+
+
 /*
  * Sets attributes and returns value indicating success.
  */
@@ -226,6 +277,25 @@ UncertMLNode::unsetElementName()
 }
 
 
+/*
+ * Unsets text and returns value indicating success.
+ */
+int
+UncertMLNode::unsetText()
+{
+  mText.erase();
+
+  if (mText.empty() == true)
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+}
+
+
 /*
  * Unsets attributes and returns value indicating success.
  */
@@ -240,14 +310,15 @@ UncertMLNode::unsetAttributes()
 unsigned int
 UncertMLNode::getNumChildren() const
 {
-  return mChildren->getSize();
+  return (unsigned int)mChildren.size();
 }
 
 
 UncertMLNode*
 UncertMLNode::getChild (unsigned int index) const
 {
-  return static_cast<UncertMLNode*>( mChildren->get(index) );
+  if ( index >= mChildren.size()) return NULL;
+  return static_cast<UncertMLNode*>( mChildren[index]);
 }
 
 
@@ -261,7 +332,8 @@ UncertMLNode::addChild(UncertMLNode * child)
   else
   {
     unsigned int numBefore = getNumChildren();
-    mChildren->add(child);
+    
+    mChildren.push_back(child);
 
     if (getNumChildren() == numBefore + 1)
     {
@@ -303,34 +375,47 @@ UncertMLNode::parseXMLNode(const XMLNode* xml)
 
   bool success = true;
 
-  // set the element name
-  if (setElementName(xml->getName()) != LIBSBML_OPERATION_SUCCESS)
-  {
-    success = false;
-  }
+  std::string name = xml->getName();
 
-  // set any attributes from teh element
-  if (xml->getAttributesLength() > 0 && success != false)
+  if (name.empty() == false)
   {
-    if (setAttributes(xml->getAttributes()) != LIBSBML_OPERATION_SUCCESS)
+    // set the element name
+    if (setElementName(xml->getName()) != LIBSBML_OPERATION_SUCCESS)
     {
       success = false;
     }
-  }
 
-  // loop thru the children of the XMLNode
-  // parse each and add as a child
-  for (unsigned int i = 0; success != false && i < xml->getNumChildren(); i++)
-  {
-    UncertMLNode * child = new UncertMLNode();
-    success = child->parseXMLNode(&(xml->getChild(i)));
-    if (success == true)
+    // set any attributes from teh element
+    if (xml->getAttributesLength() > 0 && success != false)
     {
-      if (addChild(child) != LIBSBML_OPERATION_SUCCESS)
+      if (setAttributes(xml->getAttributes()) != LIBSBML_OPERATION_SUCCESS)
       {
         success = false;
       }
     }
+
+    // loop thru the children of the XMLNode
+    // parse each and add as a child
+    for (unsigned int i = 0; success != false && i < xml->getNumChildren(); i++)
+    {
+      UncertMLNode * child = new UncertMLNode();
+      success = child->parseXMLNode(&(xml->getChild(i)));
+      if (success == true)
+      {
+        if (addChild(child) != LIBSBML_OPERATION_SUCCESS)
+        {
+          success = false;
+        }
+      }
+    }
+  }
+  else
+  {
+    // here we have a text element
+    if (setText(xml->getCharacters()) != LIBSBML_OPERATION_SUCCESS)
+    {
+      success = false;
+    }
   }
 
   return success;
@@ -352,7 +437,9 @@ UncertMLNode::constructXMLNode() const
  
   XMLNode * xml = new XMLNode(top_triple, blank_att, xmlns);
 
-  xml->addChild(*(reconstructXML()));
+  XMLNode * child = reconstructXML();
+  xml->addChild(*(child));
+  delete child;
 
   return xml;
 }
@@ -360,16 +447,26 @@ UncertMLNode::constructXMLNode() const
 XMLNode *
 UncertMLNode::reconstructXML() const
 {
-  XMLTriple triple = XMLTriple(getElementName(),"", "");
-  XMLAttributes att = XMLAttributes(getAttributes());
-
-  XMLNode * xml = new XMLNode(triple, att);
-
-  for (unsigned int n = 0; n < getNumChildren(); n++)
+  XMLNode * xml = NULL;
+  if (isSetElementName() == true)
   {
-    XMLNode * child = getChild(n)->reconstructXML();
-    xml->addChild(*(child));
+    XMLTriple triple = XMLTriple(getElementName(),"", "");
+    XMLAttributes att = XMLAttributes(getAttributes());
+
+    xml = new XMLNode(triple, att);
+
+    for (unsigned int n = 0; n < getNumChildren(); n++)
+    {
+      XMLNode * child = getChild(n)->reconstructXML();
+      xml->addChild(*(child));
+      delete child;
+    }
   }
+  else
+  {
+    xml = new XMLNode(getText());
+  }
+
   return xml;
 }
 
