@@ -8,9 +8,16 @@
  *<!---------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
- *
- * Copyright 2009-2013 California Institute of Technology.
  * 
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
+ * Copyright (C) 2009-2013 jointly by the following organizations: 
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -186,7 +193,7 @@ void
 LIBSBML_EXTERN
 void
 parseFbcAnnotation(XMLNode * annotation, ListOfGeneAssociations& associations,
-                   FbcPkgNamespaces*fbcns)
+                   FbcPkgNamespaces* fbcns)
 {
   
   if (!annotation) return;
@@ -233,7 +240,7 @@ parseFbcAnnotation(XMLNode * annotation, ListOfGeneAssociations& associations,
       
       if (name2 == "geneAssociation")
       {
-        ga = new GeneAssociation(plOGATop->getChild(n), new FbcPkgNamespaces(*fbcns));
+        ga = new GeneAssociation(plOGATop->getChild(n), fbcns);
         associations.appendAndOwn(ga);
       }
       
@@ -264,9 +271,7 @@ XMLNode* deleteFbcAnnotation(XMLNode* pAnnotation)
         pAnnotation->getChild(n).getNamespaces().getIndex(FbcExtension::getXmlnsL3V1V1()) !=-1)
     {
       // delete the anotation
-      XMLNode* temp = pAnnotation->removeChild(n);
-      if (temp != NULL)
-        delete temp;
+      delete pAnnotation->removeChild(n);
 
       continue;
     }
@@ -314,8 +319,8 @@ FbcModelPlugin::writeAttributes (XMLOutputStream& stream) const
   if (annt && annt->getNumChildren() > 0)
   {
     parent->appendAnnotation(annt);
-    delete annt;
   }
+  delete annt;
 }
 /** @endcond */
 
@@ -436,6 +441,8 @@ FbcModelPlugin::readOtherXML (SBase* parentObject, XMLInputStream& stream)
       
       readAnnotationFromStream = true;
     }
+    
+    delete fbcns;
   }
   catch(...)
   {
@@ -531,9 +538,10 @@ FbcModelPlugin::appendFrom(const Model* model)
   const FbcModelPlugin* modplug = 
     static_cast<const FbcModelPlugin*>(model->getPlugin(getPrefix()));
   
+  // absence of a plugin is not an error
   if (modplug==NULL)
   {
-    return LIBSBML_INVALID_OBJECT;
+    return LIBSBML_OPERATION_SUCCESS;
   }
 
   Model* parent = static_cast<Model*>(getParentSBMLObject());
@@ -719,6 +727,7 @@ FluxBound*
   {
     FBC_CREATE_NS(fbcns, getSBMLNamespaces());
     bound = new FluxBound(fbcns);
+    delete fbcns;
   }
   catch(...)
   {
@@ -936,10 +945,10 @@ Objective*
   Objective* objective = NULL;
 
   try
-  {  
-    
+  {      
     FBC_CREATE_NS(fbcns, getSBMLNamespaces());
     objective = new Objective(fbcns);
+    delete fbcns;
   }
   catch(...)
   {
@@ -1203,6 +1212,7 @@ GeneAssociation*
   {
     FBC_CREATE_NS(fbcns, getSBMLNamespaces());
     association = new GeneAssociation(fbcns);
+    delete fbcns;
   }
   catch(...)
   {
@@ -1371,12 +1381,13 @@ FbcModelPlugin::getFluxBoundsForReaction(const std::string& reaction) const
   {
     if (getFluxBound(i)->getReaction() == reaction)
     {
-      loFB->append(getFluxBound(i)->clone());
+      loFB->append(getFluxBound(i));
     }
   }
 
   if (loFB->size() == 0)
   {
+    delete loFB;
     loFB = NULL;
   }
 
@@ -1384,12 +1395,9 @@ FbcModelPlugin::getFluxBoundsForReaction(const std::string& reaction) const
 }
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FbcModelPlugin_addFluxBound(SBasePlugin_t * fbc, FluxBound_t * fb)
@@ -1399,9 +1407,6 @@ FbcModelPlugin_addFluxBound(SBasePlugin_t * fbc, FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 FluxBound_t *
 FbcModelPlugin_getFluxBound(SBasePlugin_t * fbc, unsigned int n)
@@ -1411,9 +1416,6 @@ FbcModelPlugin_getFluxBound(SBasePlugin_t * fbc, unsigned int n)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 unsigned int
 FbcModelPlugin_getNumFluxBounds(SBasePlugin_t * fbc)
@@ -1423,9 +1425,6 @@ FbcModelPlugin_getNumFluxBounds(SBasePlugin_t * fbc)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FbcModelPlugin_addObjective(SBasePlugin_t * fbc, Objective_t * obj)
@@ -1435,9 +1434,6 @@ FbcModelPlugin_addObjective(SBasePlugin_t * fbc, Objective_t * obj)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 Objective_t *
 FbcModelPlugin_getObjective(SBasePlugin_t * fbc, unsigned int n)
@@ -1447,9 +1443,6 @@ FbcModelPlugin_getObjective(SBasePlugin_t * fbc, unsigned int n)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 unsigned int
 FbcModelPlugin_getNumObjectives(SBasePlugin_t * fbc)
@@ -1459,9 +1452,6 @@ FbcModelPlugin_getNumObjectives(SBasePlugin_t * fbc)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 char *
 FbcModelPlugin_getActiveObjectiveId(SBasePlugin_t * fbc)
@@ -1475,12 +1465,9 @@ FbcModelPlugin_getActiveObjectiveId(SBasePlugin_t * fbc)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
-FbcModelPlugin_setActiveObjectiveId(SBasePlugin_t * fbc, char * activeId)
+FbcModelPlugin_setActiveObjectiveId(SBasePlugin_t * fbc, const char * activeId)
 {
   return (fbc != NULL) 
     ? static_cast<FbcModelPlugin *>(fbc)->setActiveObjectiveId(activeId) 
