@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -202,8 +207,8 @@ ReactionGlyph::ReactionGlyph(const XMLNode& node, unsigned int l2version)
                 this->mCurve.addCurveSegment(pTmpCurve->getCurveSegment(i));
             }
             // we also have to copy mAnnotations, mNotes, mCVTerms and mHistory
-            if(pTmpCurve->isSetNotes()) this->mCurve.setNotes(new XMLNode(*pTmpCurve->getNotes()));
-            if(pTmpCurve->isSetAnnotation()) this->mCurve.setAnnotation(new XMLNode(*pTmpCurve->getAnnotation()));
+            if(pTmpCurve->isSetNotes()) this->mCurve.setNotes(pTmpCurve->getNotes());
+            if(pTmpCurve->isSetAnnotation()) this->mCurve.setAnnotation(pTmpCurve->getAnnotation());
             if(pTmpCurve->getCVTerms()!=NULL)
             {
               iMax=pTmpCurve->getCVTerms()->getSize(); 
@@ -467,6 +472,7 @@ ReactionGlyph::createSpeciesReferenceGlyph ()
   SpeciesReferenceGlyph* srg = new SpeciesReferenceGlyph(layoutns);
 
   this->mSpeciesReferenceGlyphs.appendAndOwn(srg);
+  delete layoutns;
   return srg;
 }
 
@@ -935,6 +941,7 @@ ListOfSpeciesReferenceGlyphs::createObject (XMLInputStream& stream)
     LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
     object = new SpeciesReferenceGlyph(layoutns);
     appendAndOwn(object);
+    delete layoutns;
 //    mItems.push_back(object);
   }
 
@@ -1026,10 +1033,8 @@ ReactionGlyph::enablePackageInternal(const std::string& pkgURI,
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-/**
- * Creates a new ReactionGlyph and returns the pointer to it.
- */
+/** @cond doxygenIgnored */
+
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_create (void)
@@ -1038,9 +1043,6 @@ ReactionGlyph_create (void)
 }
 
 
-/**
- * Creates a new ReactionGlyph with the given @p id
- */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_createWith (const char *sid)
@@ -1050,9 +1052,6 @@ ReactionGlyph_createWith (const char *sid)
 }
 
 
-/**
- * Creates a new ReactionGlyph referencing the give reaction.
- */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_createWithReactionId (const char *id, const char *reactionId)
@@ -1062,9 +1061,6 @@ ReactionGlyph_createWithReactionId (const char *id, const char *reactionId)
 }
 
 
-/**
- * Creates a new ReactionGlyph object from a template.
- */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_createFrom (const ReactionGlyph_t *temp)
@@ -1073,9 +1069,6 @@ ReactionGlyph_createFrom (const ReactionGlyph_t *temp)
 }
 
 
-/**
- * Frees the memory taken up by the attributes.
- */
 LIBSBML_EXTERN
 void
 ReactionGlyph_free (ReactionGlyph_t *rg)
@@ -1084,213 +1077,163 @@ ReactionGlyph_free (ReactionGlyph_t *rg)
 }
 
 
-/**
- * Sets the reference reaction for the reaction glyph.
- */
 LIBSBML_EXTERN
 void
 ReactionGlyph_setReactionId (ReactionGlyph_t *rg,const char *id)
 {
-    static_cast<ReactionGlyph*>(rg)->setReactionId( id ? id : "" );
+  if (rg == NULL) return;
+  static_cast<ReactionGlyph*>(rg)->setReactionId( id ? id : "" );
 }
 
 
-/**
- * Gets the reference reactions id for the given reaction glyph.
- */
 LIBSBML_EXTERN
 const char *
 ReactionGlyph_getReactionId (const ReactionGlyph_t *rg)
 {
-    return rg->isSetReactionId() ? rg->getReactionId().c_str() : NULL;
+  if (rg == NULL) return NULL;
+  return rg->isSetReactionId() ? rg->getReactionId().c_str() : NULL;
 }
 
 
-/**
- * Returns 0 if the reference reaction has not been set for this glyph and
- * 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 ReactionGlyph_isSetReactionId (const ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return (int)false;
   return static_cast<int>( rg->isSetReactionId() );
 }
 
 
-/**
- * Add a SpeciesReferenceGlyph object to the list of
- * SpeciesReferenceGlyphs.
- */
 LIBSBML_EXTERN
 void
 ReactionGlyph_addSpeciesReferenceGlyph (ReactionGlyph_t         *rg,
                                         SpeciesReferenceGlyph_t *srg)
 {
+  if (rg == NULL) return;
   rg->addSpeciesReferenceGlyph(srg);
 }
 
 
-/**
- * Returns the number of SpeciesReferenceGlyphs for the ReactionGlyph.
- */
 LIBSBML_EXTERN
 unsigned int
 ReactionGlyph_getNumSpeciesReferenceGlyphs (const ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return 0;
   return rg->getNumSpeciesReferenceGlyphs();
 }
 
 
-/**
- * Returns the pointer to the SpeciesReferenceGlyphs for the given index.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 ReactionGlyph_getSpeciesReferenceGlyph (ReactionGlyph_t *rg,
                                         unsigned int           index)
 {
+  if (rg == NULL) return NULL;
   return rg->getSpeciesReferenceGlyph(index);
 }
 
 
-/**
- * Returns the list object that holds all species reference glyphs.
- */ 
 LIBSBML_EXTERN
 ListOf_t *
 ReactionGlyph_getListOfSpeciesReferenceGlyphs (ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getListOfSpeciesReferenceGlyphs();
 }
 
 
-/**
- * Calls initDefaults from GraphicalObject.
- */ 
 LIBSBML_EXTERN
 void
 ReactionGlyph_initDefaults (ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return;
   rg->initDefaults();
 }
 
 
-/**
- * Sets the curve for the reaction glyph.
- */
 LIBSBML_EXTERN
 void
 ReactionGlyph_setCurve (ReactionGlyph_t *rg, Curve_t *c)
 {
+  if (rg == NULL) return;
   rg->setCurve(c);
 }
 
 
-/**
- * Gets the Curve for the given reaction glyph.
- */
 LIBSBML_EXTERN
 Curve_t *
 ReactionGlyph_getCurve (ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getCurve();
 }
 
 
-/**
- * Returns true if the Curve has one or more LineSegment.
- */
 LIBSBML_EXTERN
 int
 ReactionGlyph_isSetCurve (ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return (int)false;
   return static_cast<int>( rg->isSetCurve() );
 }
 
 
-/**
- * Creates a new SpeciesReferenceGlyph_t object, adds it to the end of the
- * list of species reference objects and returns a pointer to the newly
- * created object.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 ReactionGlyph_createSpeciesReferenceGlyph (ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->createSpeciesReferenceGlyph();
 }
 
 
-/**
- * Creates a new LineSegment object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 ReactionGlyph_createLineSegment (ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getCurve()->createLineSegment();
 }
 
 
-/**
- * Creates a new CubicBezier object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 ReactionGlyph_createCubicBezier (ReactionGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getCurve()->createCubicBezier();
 }
 
 
-/**
- * Remove the species reference glyph with the given index.
- * A pointer to the object is returned. If no object has been removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t*
 ReactionGlyph_removeSpeciesReferenceGlyph(ReactionGlyph_t* rg,unsigned int index)
 {
-    return rg->removeSpeciesReferenceGlyph(index);
+  if (rg == NULL) return NULL;
+  return rg->removeSpeciesReferenceGlyph(index);
 }
 
-/**
- * Remove the species reference glyph with the given @p id.
- * A pointer to the object is returned. If no object has been removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t*
 ReactionGlyph_removeSpeciesReferenceGlyphWithId(ReactionGlyph_t* rg,const char* id)
 {
-    return rg->removeSpeciesReferenceGlyph(id);
+  if (rg == NULL) return NULL;
+  return rg->removeSpeciesReferenceGlyph(id);
 }
 
-/**
- * Returns the index of the species reference glyph with the given @p id.
- * If the reaction glyph does not contain a species reference glyph with this
- * id, UINT_MAX from limits.h is returned.
- */
 LIBSBML_EXTERN
 unsigned int
 ReactionGlyph_getIndexForSpeciesReferenceGlyph(ReactionGlyph_t* rg,const char* id)
 {
-    return rg->getIndexForSpeciesReferenceGlyph(id);
+  if (rg == NULL) return 0;
+  return rg->getIndexForSpeciesReferenceGlyph(id);
 }
 
-/**
- * @return a (deep) copy of this ReactionGlyph.
- */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_clone (const ReactionGlyph_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<ReactionGlyph*>( m->clone() );
 }
 
