@@ -118,7 +118,7 @@ MultiReactionPlugin::createObject (XMLInputStream& stream)
 {
   SBase* object = NULL; 
 
-  const std::string&      name   = stream.peek().getName(); 
+  //const std::string&      name   = stream.peek().getName();
   const XMLNamespaces&    xmlns  = stream.peek().getNamespaces(); 
   const std::string&      prefix = stream.peek().getPrefix(); 
 
@@ -210,7 +210,7 @@ MultiReactionPlugin::readAttributes (const XMLAttributes& attributes,
     }
   }
 
-  bool assigned = false;
+  //bool assigned = false;
 
   //
   // isIntraSpeciesReaction bool   ( use = "optional" )
@@ -265,7 +265,7 @@ MultiReactionPlugin::writeAttributes (XMLOutputStream& stream) const
 /*
  * Returns the value of the "isIntraSpeciesReaction" attribute of this MultiReactionPlugin.
  */
-const bool
+bool
 MultiReactionPlugin::getIsIntraSpeciesReaction() const
 {
   return mIsIntraSpeciesReaction;
@@ -310,7 +310,7 @@ List*
 MultiReactionPlugin::getAllElements(ElementFilter* filter)
 {
   List* ret = new List();
-  List* sublist = NULL;
+  //List* sublist = NULL;
 
 
   return ret;
