@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -30,6 +30,8 @@
 #include <sbml/packages/multi/sbml/MultiSpeciesType.h>
 #include <sbml/packages/multi/validator/MultiSBMLError.h>
 
+#include <sbml/util/ElementFilter.h>
+
 
 using namespace std;
 
@@ -185,7 +187,7 @@ MultiSpeciesType::getName() const
 /*
  * Returns the value of the "isBindingSite" attribute of this MultiSpeciesType.
  */
-const bool
+bool
 MultiSpeciesType::getIsBindingSite() const
 {
   return mIsBindingSite;
@@ -510,6 +512,7 @@ MultiSpeciesType::createSpeciesFeatureType()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     sft = new SpeciesFeatureType(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -666,6 +669,7 @@ MultiSpeciesType::createSpeciesTypeInstance()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     sti = new SpeciesTypeInstance(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -822,6 +826,7 @@ MultiSpeciesType::createSpeciesTypeComponentIndex()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     stci = new SpeciesTypeComponentIndex(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -978,6 +983,7 @@ MultiSpeciesType::createInSpeciesTypeBond()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     istb = new InSpeciesTypeBond(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -1220,6 +1226,7 @@ MultiSpeciesType::createObject(XMLInputStream& stream)
     object = &mInSpeciesTypeBonds;
   }
 
+  delete multins;
   return object;
 }
 
@@ -1333,9 +1340,10 @@ MultiSpeciesType::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<MultiSpeciesType>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
+        "The syntax of the attribute id='" + mId + "' does not conform.");
     }
   }
   else
@@ -1596,6 +1604,7 @@ ListOfMultiSpeciesTypes::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new MultiSpeciesType(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -1619,7 +1628,8 @@ ListOfMultiSpeciesTypes::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
@@ -1632,7 +1642,7 @@ ListOfMultiSpeciesTypes::writeXMLNS(XMLOutputStream& stream) const
   /** @endcond doxygenLibsbmlInternal */
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -1644,7 +1654,7 @@ MultiSpeciesType_create(unsigned int level, unsigned int version,
 }
 
 
-/**
+/*
  * 
  */
 LIBSBML_EXTERN
@@ -1656,8 +1666,8 @@ MultiSpeciesType_free(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 MultiSpeciesType_t *
@@ -1674,8 +1684,8 @@ MultiSpeciesType_clone(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -1688,8 +1698,8 @@ MultiSpeciesType_getId(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -1702,8 +1712,8 @@ MultiSpeciesType_getName(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1713,8 +1723,8 @@ MultiSpeciesType_getIsBindingSite(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 char *
@@ -1727,8 +1737,8 @@ MultiSpeciesType_getCompartment(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1738,8 +1748,8 @@ MultiSpeciesType_isSetId(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1749,8 +1759,8 @@ MultiSpeciesType_isSetName(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1760,8 +1770,8 @@ MultiSpeciesType_isSetIsBindingSite(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1771,8 +1781,8 @@ MultiSpeciesType_isSetCompartment(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1782,8 +1792,8 @@ MultiSpeciesType_setId(MultiSpeciesType_t * mst, const char * id)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1793,8 +1803,8 @@ MultiSpeciesType_setName(MultiSpeciesType_t * mst, const char * name)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1804,8 +1814,8 @@ MultiSpeciesType_setIsBindingSite(MultiSpeciesType_t * mst, int isBindingSite)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1815,8 +1825,8 @@ MultiSpeciesType_setCompartment(MultiSpeciesType_t * mst, const char * compartme
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1826,8 +1836,8 @@ MultiSpeciesType_unsetId(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1837,8 +1847,8 @@ MultiSpeciesType_unsetName(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1848,8 +1858,8 @@ MultiSpeciesType_unsetIsBindingSite(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1859,8 +1869,8 @@ MultiSpeciesType_unsetCompartment(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 int
@@ -1870,8 +1880,8 @@ MultiSpeciesType_hasRequiredAttributes(MultiSpeciesType_t * mst)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 MultiSpeciesType_t *
@@ -1884,8 +1894,8 @@ ListOfMultiSpeciesTypes_getById(ListOf_t * lo, const char * sid)
 }
 
 
-/**
- * 
+/*
+ *
  */
 LIBSBML_EXTERN
 MultiSpeciesType_t *
