@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -222,7 +222,7 @@ public:
    *
    * @return the value of the "isBindingSite" attribute of this MultiSpeciesType as a boolean.
    */
-  virtual const bool getIsBindingSite() const;
+  virtual bool getIsBindingSite() const;
 
 
   /**
