@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -30,6 +30,8 @@
 #include <sbml/packages/multi/sbml/SpeciesFeature.h>
 #include <sbml/packages/multi/validator/MultiSBMLError.h>
 
+#include <sbml/util/ElementFilter.h>
+
 
 using namespace std;
 
@@ -173,7 +175,7 @@ SpeciesFeature::getSpeciesFeatureType() const
 /*
  * Returns the value of the "occur" attribute of this SpeciesFeature.
  */
-const unsigned int
+unsigned int
 SpeciesFeature::getOccur() const
 {
   return mOccur;
@@ -510,6 +512,7 @@ SpeciesFeature::createSpeciesFeatureValue()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     sfv = new SpeciesFeatureValue(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -721,6 +724,7 @@ SpeciesFeature::createObject(XMLInputStream& stream)
     object = &mSpeciesFeatureValues;
   }
 
+  delete multins;
   return object;
 }
 
@@ -834,9 +838,10 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<SpeciesFeature>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
+        "The syntax of the attribute id='" + mId + "' does not conform.");
     }
   }
 
@@ -853,9 +858,9 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mSpeciesFeatureType, getLevel(), getVersion(), "<SpeciesFeature>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mSpeciesFeatureType) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mSpeciesFeatureType) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute speciesFeatureType='" + mSpeciesFeatureType 
         + "' does not conform.");
     }
@@ -906,9 +911,9 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mComponent, getLevel(), getVersion(), "<SpeciesFeature>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mComponent) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mComponent) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute component='" + mComponent + "' does not conform.");
     }
   }
@@ -1205,6 +1210,7 @@ ListOfSpeciesFeatures::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new SpeciesFeature(multins);
     appendAndOwn(object);
+    delete multins;
   }
   else if ( name == "subListOfSpeciesFeatures")
   {
@@ -1212,6 +1218,7 @@ ListOfSpeciesFeatures::createObject(XMLInputStream& stream)
     object = new ListOfSpeciesFeatures(multins);
     static_cast<ListOfSpeciesFeatures*>(object)->setIsSubList();
     mSubListOfSpeciesFeatures->add(object);
+    delete multins;
   }
 
   return object;
@@ -1235,7 +1242,8 @@ ListOfSpeciesFeatures::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
