@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -30,6 +30,8 @@
 #include <sbml/packages/multi/sbml/SpeciesFeatureType.h>
 #include <sbml/packages/multi/validator/MultiSBMLError.h>
 
+#include <sbml/util/ElementFilter.h>
+
 
 using namespace std;
 
@@ -169,7 +171,7 @@ SpeciesFeatureType::getName() const
 /*
  * Returns the value of the "occur" attribute of this SpeciesFeatureType.
  */
-const unsigned int
+unsigned int
 SpeciesFeatureType::getOccur() const
 {
   return mOccur;
@@ -441,6 +443,7 @@ SpeciesFeatureType::createPossibleSpeciesFeatureValue()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     psfv = new PossibleSpeciesFeatureValue(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -633,6 +636,7 @@ SpeciesFeatureType::createObject(XMLInputStream& stream)
     object = &mPossibleSpeciesFeatureValues;
   }
 
+  delete multins;
   return object;
 }
 
@@ -745,9 +749,10 @@ SpeciesFeatureType::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<SpeciesFeatureType>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
+        "The syntax of the attribute id='" + mId + "' does not conform.");
     }
   }
   else
@@ -985,6 +990,7 @@ ListOfSpeciesFeatureTypes::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new SpeciesFeatureType(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -1008,7 +1014,8 @@ ListOfSpeciesFeatureTypes::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
