@@ -92,6 +92,12 @@ public:
   GlobalRenderInformation (RenderPkgNamespaces* renderns);
 
 
+  /**
+   * Destroy this GlobalRenderInformation object.
+   */
+  virtual ~GlobalRenderInformation ();
+
+
   /**
    * Parses the xml information in the given node and sets the attributes.
    * This method should never be called by the user. It is only used to read render 
