@@ -142,6 +142,13 @@ protected:
 #endif // OMIT_DEPRECATED
 
 public:
+
+  /**
+   * Destroy this GradientBase object.
+   */
+  virtual ~GradientBase ();
+
+
   /**
    * Returns the spreadmethod of the gradient.
    * Valid values are GradientBase::PAD, GradientBase::REFLECT
