@@ -501,6 +501,9 @@ AnalyticVolume::hasRequiredAttributes () const
   if (isSetFunctionType() == false)
     allPresent = false;
 
+  if (isSetOrdinal() == false)
+    allPresent = false;
+
   if (isSetDomainType() == false)
     allPresent = false;
 
@@ -638,7 +641,7 @@ AnalyticVolume::readAttributes (const XMLAttributes& attributes,
               getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
@@ -646,7 +649,7 @@ AnalyticVolume::readAttributes (const XMLAttributes& attributes,
                    getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                  getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                  getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
     }
   }
@@ -665,7 +668,7 @@ AnalyticVolume::readAttributes (const XMLAttributes& attributes,
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
@@ -673,7 +676,7 @@ AnalyticVolume::readAttributes (const XMLAttributes& attributes,
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
     }
   }
@@ -696,40 +699,43 @@ AnalyticVolume::readAttributes (const XMLAttributes& attributes,
     else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
       getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute id='" + mId + "' does not conform.");
+        "The syntax of the attribute id='" + mId + "' does not conform.", getLine(), getColumn());
     }
   }
   else
   {
-    std::string message = "Spatial attribute 'id' is missing.";
+    std::string message = "Spatial attribute 'id' is missing from 'analyticVolume' object.";
     getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
   }
 
   //
   // functionType enum  ( use = "required" )
   //
-  mFunctionType = FUNCTIONKIND_UNKNOWN;
-  {
-    std::string stringValue;
-    assigned = attributes.readInto("functionType", stringValue);
+   mFunctionType = FUNCTIONKIND_UNKNOWN;
+   std::string stringValue;
+   assigned = attributes.readInto("functionType", stringValue);
 
-    if (assigned == true)
-    {
-      // parse enum
+   if (assigned == true)
+   {
+     // parse enum
 
-      mFunctionType = FunctionKind_parse(stringValue.c_str());
-    }
-  }
-  if(mFunctionType == FUNCTIONKIND_UNKNOWN)
-  {
-    std::string message = "Spatial attribute 'functionType' is missing.";
+     mFunctionType = FunctionKind_parse(stringValue.c_str());
+     if(mFunctionType == FUNCTIONKIND_UNKNOWN) {
+       std::string message = "Unknown value for spatial attribute 'functionType' in 'analyticVolume' object: " + stringValue;
+       getErrorLog()->logPackageError("spatial", SpatialUnknownError,
+         getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
+     }
+   }
+   if(mFunctionType == FUNCTIONKIND_UNKNOWN)
+   {
+    std::string message = "Spatial attribute 'functionType' is missing from 'analyticVolume' object.";
     getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
   }
 
   //
-  // ordinal int   ( use = "optional" )
+  // ordinal int   ( use = "required" )
   //
   numErrs = getErrorLog()->getNumErrors();
   mIsSetOrdinal = attributes.readInto("ordinal", mOrdinal);
@@ -743,7 +749,13 @@ AnalyticVolume::readAttributes (const XMLAttributes& attributes,
       {
         getErrorLog()->remove(XMLAttributeTypeMismatch);
         getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                     getPackageVersion(), sbmlLevel, sbmlVersion);
+                     getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
+      }
+      else
+      {
+        std::string message = "Spatial attribute 'ordinal' is missing from 'analyticVolume' object.";
+        getErrorLog()->logPackageError("spatial", SpatialUnknownError,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, message);
       }
     }
   }
@@ -769,9 +781,9 @@ AnalyticVolume::readAttributes (const XMLAttributes& attributes,
   }
   else
   {
-    std::string message = "Spatial attribute 'domainType' is missing.";
+    std::string message = "Spatial attribute 'domainType' is missing from 'analyticVolume' object.";
     getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
   }
 
 }
