@@ -547,7 +547,7 @@ BoundaryCondition::readAttributes (const XMLAttributes& attributes,
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
@@ -555,7 +555,7 @@ BoundaryCondition::readAttributes (const XMLAttributes& attributes,
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
     }
   }
@@ -583,31 +583,34 @@ BoundaryCondition::readAttributes (const XMLAttributes& attributes,
   }
   else
   {
-    std::string message = "Spatial attribute 'variable' is missing.";
+    std::string message = "Spatial attribute 'variable' is missing from 'boundaryCondition' object.";
     getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
   }
 
   //
   // type enum  ( use = "required" )
   //
   mType = BOUNDARYCONDITIONKIND_UNKNOWN;
+  std::string stringValue;
+  assigned = attributes.readInto("type", stringValue);
+
+  if (assigned == true)
   {
-    std::string stringValue;
-    assigned = attributes.readInto("type", stringValue);
+    // parse enum
 
-    if (assigned == true)
-    {
-      // parse enum
-
-      mType = BoundaryConditionKind_parse(stringValue.c_str());
+    mType = BoundaryConditionKind_parse(stringValue.c_str());
+    if(mType == BOUNDARYCONDITIONKIND_UNKNOWN) {
+      std::string message = "Unknown value for spatial attribute 'type' in 'boundaryCondition' object: " + stringValue;
+      getErrorLog()->logPackageError("spatial", SpatialUnknownError,
+        getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
     }
   }
   if(mType == BOUNDARYCONDITIONKIND_UNKNOWN)
   {
-    std::string message = "Spatial attribute 'type' is missing.";
+    std::string message = "Spatial attribute 'type' is missing from 'boundaryCondition' object.";
     getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-                   getPackageVersion(), sbmlLevel, sbmlVersion, message);
+                   getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
   }
 
   //
