@@ -58,6 +58,7 @@ class AnalyticGeometry;
 class SampledFieldGeometry;
 class CSGeometry;
 class ParametricGeometry;
+class MixedGeometry;
 
 
 
@@ -67,6 +68,8 @@ class LIBSBML_EXTERN GeometryDefinition : public SBase
 protected:
 
   std::string   mId;
+  bool          mIsActive;
+  bool          mIsSetIsActive;
 
 
 public:
@@ -132,6 +135,14 @@ public:
   virtual const std::string& getId() const;
 
 
+  /**
+   * Returns the value of the "isActive" attribute of this GeometryDefinition.
+   *
+   * @return the value of the "isActive" attribute of this GeometryDefinition as a boolean.
+   */
+  virtual bool getIsActive() const;
+
+
   /**
    * Predicate returning @c true or @c false depending on whether this
    * GeometryDefinition's "id" attribute has been set.
@@ -142,6 +153,16 @@ public:
   virtual bool isSetId() const;
 
 
+  /**
+   * Predicate returning @c true or @c false depending on whether this
+   * GeometryDefinition's "isActive" attribute has been set.
+   *
+   * @return @c true if this GeometryDefinition's "isActive" attribute has been set,
+   * otherwise @c false is returned.
+   */
+  virtual bool isSetIsActive() const;
+
+
   /**
    * Sets the value of the "id" attribute of this GeometryDefinition.
    *
@@ -157,6 +178,21 @@ public:
   virtual int setId(const std::string& id);
 
 
+  /**
+   * Sets the value of the "isActive" attribute of this GeometryDefinition.
+   *
+   * @param isActive; bool value of the "isActive" attribute to be set
+   *
+   * @return integer value indicating success/failure of the
+   * function.  @if clike The value is drawn from the
+   * enumeration #OperationReturnValues_t. @endif The possible values
+   * returned by this function are:
+   * @li LIBSBML_OPERATION_SUCCESS
+   * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
+   */
+  virtual int setIsActive(bool isActive);
+
+
   /**
    * Unsets the value of the "id" attribute of this GeometryDefinition.
    *
@@ -170,6 +206,19 @@ public:
   virtual int unsetId();
 
 
+  /**
+   * Unsets the value of the "isActive" attribute of this GeometryDefinition.
+   *
+   * @return integer value indicating success/failure of the
+   * function.  @if clike The value is drawn from the
+   * enumeration #OperationReturnValues_t. @endif The possible values
+   * returned by this function are:
+   * @li LIBSBML_OPERATION_SUCCESS
+   * @li LIBSBML_OPERATION_FAILED
+   */
+  virtual int unsetIsActive();
+
+
   /**
    * Returns @c true, if this abstract "GeometryDefinition" is of type AnalyticGeometry.
    *
@@ -206,6 +255,15 @@ public:
   virtual bool isParametricGeometry() const;
 
 
+  /**
+   * Returns @c true, if this abstract "GeometryDefinition" is of type MixedGeometry.
+   *
+   * @return @c true, if this abstract "GeometryDefinition" is of type MixedGeometry.
+   *
+   */
+  virtual bool isMixedGeometry() const;
+
+
   /**
    * Returns the XML element name of this object, which for GeometryDefinition, is
    * always @c "geometryDefinition".
@@ -254,6 +312,7 @@ public:
    *
    * @note The required attributes for a GeometryDefinition object are:
    * @li "id"
+   * @li "isActive"
    *
    * @return a boolean value indicating whether all the required
    * attributes for this object have been defined.
@@ -507,6 +566,17 @@ public:
 	ParametricGeometry* createParametricGeometry();
 
 
+	/**
+	 * Creates a new GeometryDefinition object, adds it to the
+	 * ListOfGeometryDefinitions and returns the GeometryDefinition object created. 
+	 *
+	 * @return a new GeometryDefinition object instance
+	 *
+	 * @see addGeometryDefinition(const GeometryDefinition* gd)
+	 */
+	MixedGeometry* createMixedGeometry();
+
+
   /**
    * Removes the nth GeometryDefinition from this ListOfGeometryDefinitions
    * and returns a pointer to it.
@@ -638,7 +708,7 @@ protected:
 
 	virtual bool isValidTypeForList(SBase * item) {
 		int code = item->getTypeCode();
-		return code == getItemTypeCode() || code == SBML_SPATIAL_ANALYTICGEOMETRY || code == SBML_SPATIAL_SAMPLEDFIELDGEOMETRY || code == SBML_SPATIAL_CSGEOMETRY || code == SBML_SPATIAL_PARAMETRICGEOMETRY ;
+		return code == getItemTypeCode() || code == SBML_SPATIAL_ANALYTICGEOMETRY || code == SBML_SPATIAL_SAMPLEDFIELDGEOMETRY || code == SBML_SPATIAL_CSGEOMETRY || code == SBML_SPATIAL_PARAMETRICGEOMETRY || code == SBML_SPATIAL_MIXEDGEOMETRY ;
 	}
 
 
@@ -721,6 +791,21 @@ const char *
 GeometryDefinition_getId(const GeometryDefinition_t * gd);
 
 
+/**
+ * Returns the value of the "isActive" attribute of the given GeometryDefinition_t
+ * structure.
+ *
+ * @param gd the GeometryDefinition_t structure.
+ *
+ * @return the isActive of this structure.
+ *
+ * @member of GeometryDefinition_t
+ */
+LIBSBML_EXTERN
+int
+GeometryDefinition_getIsActive(const GeometryDefinition_t * gd);
+
+
 /**
  * Predicate returning @c 1 if the given GeometryDefinition_t structure's "id"
  * is set.
@@ -737,6 +822,22 @@ int
 GeometryDefinition_isSetId(const GeometryDefinition_t * gd);
 
 
+/**
+ * Predicate returning @c 1 if the given GeometryDefinition_t structure's "isActive"
+ * is set.
+ *
+ * @param gd the GeometryDefinition_t structure.
+ *
+ * @return @c 1 if the "isActive" of this GeometryDefinition_t structure is
+ * set, @c 0 otherwise.
+ *
+ * @member of GeometryDefinition_t
+ */
+LIBSBML_EXTERN
+int
+GeometryDefinition_isSetIsActive(const GeometryDefinition_t * gd);
+
+
 /**
  * Sets the "id" attribute of the given GeometryDefinition_t structure.
  *
@@ -766,6 +867,29 @@ int
 GeometryDefinition_setId(GeometryDefinition_t * gd, const char * id);
 
 
+/**
+ * Sets the "isActive" attribute of the given GeometryDefinition_t structure.
+ *
+ * @param gd the GeometryDefinition_t structure.
+ *
+ * @param isActive the string to which the structures "isActive" attribute should be
+ * set.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @member of GeometryDefinition_t
+ */
+LIBSBML_EXTERN
+int
+GeometryDefinition_setIsActive(GeometryDefinition_t * gd, int isActive);
+
+
 /**
  * Unsets the value of the "id" attribute of the given 
  *GeometryDefinition_t structure.
@@ -787,6 +911,27 @@ int
 GeometryDefinition_unsetId(GeometryDefinition_t * gd);
 
 
+/**
+ * Unsets the value of the "isActive" attribute of the given 
+ *GeometryDefinition_t structure.
+ *
+ * @param gd the GeometryDefinition_t structure.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible values
+ * returned by this function are:
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_OPERATION_FAILED LIBSBML_OPERATION_FAILED@endlink
+ * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ *
+ * @member of GeometryDefinition_t
+ */
+LIBSBML_EXTERN
+int
+GeometryDefinition_unsetIsActive(GeometryDefinition_t * gd);
+
+
 /**
  * Predicate returning @c 1 or *c 0 depending on whether all the required
  * attributes of the given GeometryDefinition_t structure have been set.
