@@ -63,8 +63,8 @@ class LIBSBML_EXTERN ParametricObject : public SBase
 protected:
 
   std::string   mId;
-  std::string   mPolygonType;
-  std::string   mDomain;
+  PolygonKind_t   mPolygonType;
+  std::string   mDomainType;
   PolygonObject*      mPolygonObject;
 
 
@@ -134,17 +134,17 @@ public:
   /**
    * Returns the value of the "polygonType" attribute of this ParametricObject.
    *
-   * @return the value of the "polygonType" attribute of this ParametricObject as a string.
+   * @return the value of the "polygonType" attribute of this ParametricObject as a PolygonKind_t.
    */
-  virtual const std::string& getPolygonType() const;
+  virtual PolygonKind_t getPolygonType() const;
 
 
   /**
-   * Returns the value of the "domain" attribute of this ParametricObject.
+   * Returns the value of the "domainType" attribute of this ParametricObject.
    *
-   * @return the value of the "domain" attribute of this ParametricObject as a string.
+   * @return the value of the "domainType" attribute of this ParametricObject as a string.
    */
-  virtual const std::string& getDomain() const;
+  virtual const std::string& getDomainType() const;
 
 
   /**
@@ -193,12 +193,12 @@ public:
 
   /**
    * Predicate returning @c true or @c false depending on whether this
-   * ParametricObject's "domain" attribute has been set.
+   * ParametricObject's "domainType" attribute has been set.
    *
-   * @return @c true if this ParametricObject's "domain" attribute has been set,
+   * @return @c true if this ParametricObject's "domainType" attribute has been set,
    * otherwise @c false is returned.
    */
-  virtual bool isSetDomain() const;
+  virtual bool isSetDomainType() const;
 
 
   /**
@@ -229,7 +229,22 @@ public:
   /**
    * Sets the value of the "polygonType" attribute of this ParametricObject.
    *
-   * @param polygonType; const std::string& value of the "polygonType" attribute to be set
+   * @param polygonType; PolygonKind_t value of the "polygonType" attribute to be set
+   *
+   * @return integer value indicating success/failure of the
+   * function.  @if clike The value is drawn from the
+   * enumeration #OperationReturnValues_t. @endif The possible values
+   * returned by this function are:
+   * @li LIBSBML_OPERATION_SUCCESS
+   * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
+   */
+  virtual int setPolygonType(PolygonKind_t polygonType);
+
+
+  /**
+   * Sets the value of the "polygonType" attribute of this ParametricObject.
+   *
+   * @param polygonType; string value of the "polygonType" attribute to be set
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
@@ -242,9 +257,9 @@ public:
 
 
   /**
-   * Sets the value of the "domain" attribute of this ParametricObject.
+   * Sets the value of the "domainType" attribute of this ParametricObject.
    *
-   * @param domain; const std::string& value of the "domain" attribute to be set
+   * @param domainType; const std::string& value of the "domainType" attribute to be set
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
@@ -253,7 +268,7 @@ public:
    * @li LIBSBML_OPERATION_SUCCESS
    * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
    */
-  virtual int setDomain(const std::string& domain);
+  virtual int setDomainType(const std::string& domainType);
 
 
   /**
@@ -298,7 +313,7 @@ public:
 
 
   /**
-   * Unsets the value of the "domain" attribute of this ParametricObject.
+   * Unsets the value of the "domainType" attribute of this ParametricObject.
    *
    * @return integer value indicating success/failure of the
    * function.  @if clike The value is drawn from the
@@ -307,7 +322,7 @@ public:
    * @li LIBSBML_OPERATION_SUCCESS
    * @li LIBSBML_OPERATION_FAILED
    */
-  virtual int unsetDomain();
+  virtual int unsetDomainType();
 
 
   /**
@@ -396,7 +411,7 @@ public:
    * @note The required attributes for a ParametricObject object are:
    * @li "id"
    * @li "polygonType"
-   * @li "domain"
+   * @li "domainType"
    * @li "polygonObject"
    *
    * @return a boolean value indicating whether all the required
@@ -524,6 +539,265 @@ protected:
 
 
 
+};
+
+class LIBSBML_EXTERN ListOfParametricObjects : public ListOf
+{
+
+public:
+
+  /**
+   * Creates a new ListOfParametricObjects with the given level, version, and package version.
+   *
+   * @param level an unsigned int, the SBML Level to assign to this ListOfParametricObjects
+   *
+   * @param version an unsigned int, the SBML Version to assign to this ListOfParametricObjects
+   *
+   * @param pkgVersion an unsigned int, the SBML Spatial Version to assign to this ListOfParametricObjects
+   */
+  ListOfParametricObjects(unsigned int level      = SpatialExtension::getDefaultLevel(),
+                          unsigned int version    = SpatialExtension::getDefaultVersion(),
+                          unsigned int pkgVersion = SpatialExtension::getDefaultPackageVersion());
+
+
+  /**
+   * Creates a new ListOfParametricObjects with the given SpatialPkgNamespaces object.
+   *
+   * @param spatialns the SpatialPkgNamespaces object
+   */
+  ListOfParametricObjects(SpatialPkgNamespaces* spatialns);
+
+
+   /**
+   * Creates and returns a deep copy of this ListOfParametricObjects object.
+   *
+   * @return a (deep) copy of this ListOfParametricObjects object.
+   */
+  virtual ListOfParametricObjects* clone () const;
+
+
+   /**
+   * Get a ParametricObject from the ListOfParametricObjects.
+   *
+   * @param n the index number of the ParametricObject to get.
+   *
+   * @return the nth ParametricObject in this ListOfParametricObjects.
+   *
+   * @see size()
+   */
+	virtual ParametricObject* get(unsigned int n);
+
+
+  /**
+   * Get a ParametricObject from the ListOfParametricObjects.
+   *
+   * @param n the index number of the ParametricObject to get.
+   *
+   * @return the nth ParametricObject in this ListOfParametricObjects.
+   *
+   * @see size()
+   */
+	virtual const ParametricObject* get(unsigned int n) const;
+
+
+  /**
+   * Get a ParametricObject from the ListOfParametricObjects
+   * based on its identifier.
+   *
+   * @param sid a string representing the identifier
+   * of the ParametricObject to get.
+   *
+   * @return ParametricObject in this ListOfParametricObjects
+   * with the given id or NULL if no such
+   * ParametricObject exists.
+   *
+   * @see get(unsigned int n)   *
+   * @see size()
+   */
+	virtual ParametricObject* get(const std::string& sid);
+
+
+  /**
+   * Get a ParametricObject from the ListOfParametricObjects
+   * based on its identifier.
+   *
+   * @param sid a string representing the identifier
+   * of the ParametricObject to get.
+   *
+   * @return ParametricObject in this ListOfParametricObjects
+   * with the given id or NULL if no such
+   * ParametricObject exists.
+   *
+   * @see get(unsigned int n)   *
+   * @see size()
+   */
+  virtual const ParametricObject* get(const std::string& sid) const;
+
+
+	/**
+	 * Adds a copy the given "ParametricObject" to this ListOfParametricObjects.
+	 *
+	 * @param po; the ParametricObject object to add
+	 *
+	 * @return integer value indicating success/failure of the
+	 * function.  @if clike The value is drawn from the
+	 * enumeration #OperationReturnValues_t. @endif The possible values
+	 * returned by this function are:
+	 * @li LIBSEDML_OPERATION_SUCCESS
+	 * @li LIBSEDML_INVALID_ATTRIBUTE_VALUE
+	 */
+	int addParametricObject(const ParametricObject* po);
+
+
+	/**
+	 * Get the number of ParametricObject objects in this ListOfParametricObjects.
+	 *
+	 * @return the number of ParametricObject objects in this ListOfParametricObjects
+	 */
+	unsigned int getNumParametricObjects() const;
+
+
+	/**
+	 * Creates a new ParametricObject object, adds it to the
+	 * ListOfParametricObjects and returns the ParametricObject object created. 
+	 *
+	 * @return a new ParametricObject object instance
+	 *
+	 * @see addParametricObject(const ParametricObject* po)
+	 */
+	ParametricObject* createParametricObject();
+
+
+  /**
+   * Removes the nth ParametricObject from this ListOfParametricObjects
+   * and returns a pointer to it.
+   *
+   * The caller owns the returned item and is responsible for deleting it.
+   *
+   * @param n the index of the ParametricObject to remove.
+   *
+   * @see size()
+   */
+	virtual ParametricObject* remove(unsigned int n);
+
+
+  /**
+   * Removes the ParametricObject from this ListOfParametricObjects with the given identifier
+   * and returns a pointer to it.
+   *
+   * The caller owns the returned item and is responsible for deleting it.
+   * If none of the items in this list have the identifier @p sid, then
+   * @c NULL is returned.
+   *
+   * @param sid the identifier of the ParametricObject to remove.
+   *
+   * @return the ParametricObject removed. As mentioned above, the caller owns the
+   * returned item.
+   */
+	virtual ParametricObject* remove(const std::string& sid);
+
+
+  /**
+   * Returns the XML element name of this object, which for ListOfParametricObjects, is
+   * always @c "listOfParametricObjects".
+   *
+   * @return the name of this element, i.e. @c "listOfParametricObjects".
+   */
+  virtual const std::string& getElementName () const;
+
+
+  /**
+   * Returns the libSBML type code for this SBML object.
+   * 
+   * @if clike LibSBML attaches an identifying code to every kind of SBML
+   * object.  These are known as <em>SBML type codes</em>.  The set of
+   * possible type codes is defined in the enumeration #SBMLTypeCode_t.
+   * The names of the type codes all begin with the characters @c
+   * SBML_. @endif@if java LibSBML attaches an identifying code to every
+   * kind of SBML object.  These are known as <em>SBML type codes</em>.  In
+   * other languages, the set of type codes is stored in an enumeration; in
+   * the Java language interface for libSBML, the type codes are defined as
+   * static integer constants in the interface class {@link
+   * libsbmlConstants}.  The names of the type codes all begin with the
+   * characters @c SBML_. @endif@if python LibSBML attaches an identifying
+   * code to every kind of SBML object.  These are known as <em>SBML type
+   * codes</em>.  In the Python language interface for libSBML, the type
+   * codes are defined as static integer constants in the interface class
+   * @link libsbml@endlink.  The names of the type codes all begin with the
+   * characters @c SBML_. @endif@if csharp LibSBML attaches an identifying
+   * code to every kind of SBML object.  These are known as <em>SBML type
+   * codes</em>.  In the C# language interface for libSBML, the type codes
+   * are defined as static integer constants in the interface class @link
+   * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
+   * the characters @c SBML_. @endif
+   *
+   * @return the SBML type code for this object, or
+   * @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
+   *
+   * @see getElementName()
+   */
+  virtual int getTypeCode () const;
+
+
+  /**
+   * Returns the libSBML type code for the SBML objects
+   * contained in this ListOf object
+   * 
+   * @if clike LibSBML attaches an identifying code to every kind of SBML
+   * object.  These are known as <em>SBML type codes</em>.  The set of
+   * possible type codes is defined in the enumeration #SBMLTypeCode_t.
+   * The names of the type codes all begin with the characters @c
+   * SBML_. @endif@if java LibSBML attaches an identifying code to every
+   * kind of SBML object.  These are known as <em>SBML type codes</em>.  In
+   * other languages, the set of type codes is stored in an enumeration; in
+   * the Java language interface for libSBML, the type codes are defined as
+   * static integer constants in the interface class {@link
+   * libsbmlConstants}.  The names of the type codes all begin with the
+   * characters @c SBML_. @endif@if python LibSBML attaches an identifying
+   * code to every kind of SBML object.  These are known as <em>SBML type
+   * codes</em>.  In the Python language interface for libSBML, the type
+   * codes are defined as static integer constants in the interface class
+   * @link libsbml@endlink.  The names of the type codes all begin with the
+   * characters @c SBML_. @endif@if csharp LibSBML attaches an identifying
+   * code to every kind of SBML object.  These are known as <em>SBML type
+   * codes</em>.  In the C# language interface for libSBML, the type codes
+   * are defined as static integer constants in the interface class @link
+   * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
+   * the characters @c SBML_. @endif
+   *
+   * @return the SBML type code for the objects in this ListOf instance, or
+   * @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
+   *
+   * @see getElementName()
+   */
+  virtual int getItemTypeCode () const;
+
+
+protected:
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Creates a new ParametricObject in this ListOfParametricObjects
+   */
+  virtual SBase* createObject(XMLInputStream& stream);
+
+
+  /** @endcond doxygenLibsbmlInternal */
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Write the namespace for the Spatial package.
+   */
+  virtual void writeXMLNS(XMLOutputStream& stream) const;
+
+
+  /** @endcond doxygenLibsbmlInternal */
+
+
+
 };
 
 
@@ -613,23 +887,23 @@ ParametricObject_getId(const ParametricObject_t * po);
  * @member of ParametricObject_t
  */
 LIBSBML_EXTERN
-const char *
+PolygonKind_t
 ParametricObject_getPolygonType(const ParametricObject_t * po);
 
 
 /**
- * Returns the value of the "domain" attribute of the given ParametricObject_t
+ * Returns the value of the "domainType" attribute of the given ParametricObject_t
  * structure.
  *
  * @param po the ParametricObject_t structure.
  *
- * @return the domain of this structure.
+ * @return the domainType of this structure.
  *
  * @member of ParametricObject_t
  */
 LIBSBML_EXTERN
 const char *
-ParametricObject_getDomain(const ParametricObject_t * po);
+ParametricObject_getDomainType(const ParametricObject_t * po);
 
 
 LIBSBML_EXTERN
@@ -675,19 +949,19 @@ ParametricObject_isSetPolygonType(const ParametricObject_t * po);
 
 
 /**
- * Predicate returning @c 1 if the given ParametricObject_t structure's "domain"
+ * Predicate returning @c 1 if the given ParametricObject_t structure's "domainType"
  * is set.
  *
  * @param po the ParametricObject_t structure.
  *
- * @return @c 1 if the "domain" of this ParametricObject_t structure is
+ * @return @c 1 if the "domainType" of this ParametricObject_t structure is
  * set, @c 0 otherwise.
  *
  * @member of ParametricObject_t
  */
 LIBSBML_EXTERN
 int
-ParametricObject_isSetDomain(const ParametricObject_t * po);
+ParametricObject_isSetDomainType(const ParametricObject_t * po);
 
 
 /**
@@ -738,9 +1012,6 @@ ParametricObject_setId(ParametricObject_t * po, const char * id);
 /**
  * Sets the "polygonType" attribute of the given ParametricObject_t structure.
  *
- * This function copies the string given in @p string.  If the string is
- * a null pointer, this function performs ParametricObject_unsetPolygonType() instead.
- *
  * @param po the ParametricObject_t structure.
  *
  * @param polygonType the string to which the structures "polygonType" attribute should be
@@ -754,25 +1025,22 @@ ParametricObject_setId(ParametricObject_t * po, const char * id);
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE@endlink
  * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
  *
- * @note Using this function with a null pointer for @p name is equivalent to
- * unsetting the value of the "name" attribute.
- * 
  * @member of ParametricObject_t
  */
 LIBSBML_EXTERN
 int
-ParametricObject_setPolygonType(ParametricObject_t * po, const char * polygonType);
+ParametricObject_setPolygonType(ParametricObject_t * po, PolygonKind_t polygonType);
 
 
 /**
- * Sets the "domain" attribute of the given ParametricObject_t structure.
+ * Sets the "domainType" attribute of the given ParametricObject_t structure.
  *
  * This function copies the string given in @p string.  If the string is
- * a null pointer, this function performs ParametricObject_unsetDomain() instead.
+ * a null pointer, this function performs ParametricObject_unsetDomainType() instead.
  *
  * @param po the ParametricObject_t structure.
  *
- * @param domain the string to which the structures "domain" attribute should be
+ * @param domainType the string to which the structures "domainType" attribute should be
  * set.
  *
  * @return integer value indicating success/failure of the
@@ -790,7 +1058,7 @@ ParametricObject_setPolygonType(ParametricObject_t * po, const char * polygonTyp
  */
 LIBSBML_EXTERN
 int
-ParametricObject_setDomain(ParametricObject_t * po, const char * domain);
+ParametricObject_setDomainType(ParametricObject_t * po, const char * domainType);
 
 
 LIBSBML_EXTERN
@@ -841,7 +1109,7 @@ ParametricObject_unsetPolygonType(ParametricObject_t * po);
 
 
 /**
- * Unsets the value of the "domain" attribute of the given 
+ * Unsets the value of the "domainType" attribute of the given 
  *ParametricObject_t structure.
  *
  * @param po the ParametricObject_t structure.
@@ -858,7 +1126,7 @@ ParametricObject_unsetPolygonType(ParametricObject_t * po);
  */
 LIBSBML_EXTERN
 int
-ParametricObject_unsetDomain(ParametricObject_t * po);
+ParametricObject_unsetDomainType(ParametricObject_t * po);
 
 
 /**
@@ -893,6 +1161,16 @@ int
 ParametricObject_hasRequiredElements(const ParametricObject_t * po);
 
 
+LIBSBML_EXTERN
+ParametricObject_t *
+ListOfParametricObjects_getById(ListOf_t * lo, const char * sid);
+
+
+LIBSBML_EXTERN
+ParametricObject_t *
+ListOfParametricObjects_removeById(ListOf_t * lo, const char * sid);
+
+
 
 
 END_C_DECLS
