@@ -148,7 +148,6 @@ struct SpatialValidatorConstraints
   ConstraintSet<CoordinateComponent>      mCoordinateComponent;
   ConstraintSet<SampledFieldGeometry>      mSampledFieldGeometry;
   ConstraintSet<SampledField>      mSampledField;
-  ConstraintSet<ImageData>      mImageData;
   ConstraintSet<SampledVolume>      mSampledVolume;
   ConstraintSet<AnalyticGeometry>      mAnalyticGeometry;
   ConstraintSet<AnalyticVolume>      mAnalyticVolume;
@@ -174,6 +173,8 @@ struct SpatialValidatorConstraints
   ConstraintSet<BoundaryCondition>      mBoundaryCondition;
   ConstraintSet<Geometry>      mGeometry;
   ConstraintSet<CoordinateReference>      mCoordinateReference;
+  ConstraintSet<MixedGeometry>      mMixedGeometry;
+  ConstraintSet<OrdinalMapping>      mOrdinalMapping;
   map<VConstraint*,bool> ptrMap;
 
   ~SpatialValidatorConstraints ();
@@ -283,12 +284,6 @@ SpatialValidatorConstraints::add (VConstraint* c)
     return;
   }
 
-  if (dynamic_cast< TConstraint<ImageData>* >(c) != NULL)
-  {
-    mImageData.add( static_cast< TConstraint<ImageData>* >(c) );
-    return;
-  }
-
   if (dynamic_cast< TConstraint<SampledVolume>* >(c) != NULL)
   {
     mSampledVolume.add( static_cast< TConstraint<SampledVolume>* >(c) );
@@ -439,6 +434,18 @@ SpatialValidatorConstraints::add (VConstraint* c)
     return;
   }
 
+  if (dynamic_cast< TConstraint<MixedGeometry>* >(c) != NULL)
+  {
+    mMixedGeometry.add( static_cast< TConstraint<MixedGeometry>* >(c) );
+    return;
+  }
+
+  if (dynamic_cast< TConstraint<OrdinalMapping>* >(c) != NULL)
+  {
+    mOrdinalMapping.add( static_cast< TConstraint<OrdinalMapping>* >(c) );
+    return;
+  }
+
 }
 
 // ----------------------------------------------------------------------
@@ -463,6 +470,9 @@ class SpatialValidatingVisitor: public SBMLVisitor
 public:
 
   SpatialValidatingVisitor (SpatialValidator& v, const Model& m) : v(v), m(m) { }
+
+  using SBMLVisitor::visit;
+
   bool visit (const DomainType &x)
   {
     v.mSpatialConstraints->mDomainType.applyTo(m, x);
@@ -523,12 +533,6 @@ public:
     return !v.mSpatialConstraints->mSampledField.empty();
   }
 
-  bool visit (const ImageData &x)
-  {
-    v.mSpatialConstraints->mImageData.applyTo(m, x);
-    return !v.mSpatialConstraints->mImageData.empty();
-  }
-
   bool visit (const SampledVolume &x)
   {
     v.mSpatialConstraints->mSampledVolume.applyTo(m, x);
@@ -679,6 +683,18 @@ public:
     return !v.mSpatialConstraints->mCoordinateReference.empty();
   }
 
+  bool visit (const MixedGeometry &x)
+  {
+    v.mSpatialConstraints->mMixedGeometry.applyTo(m, x);
+    return !v.mSpatialConstraints->mMixedGeometry.empty();
+  }
+
+  bool visit (const OrdinalMapping &x)
+  {
+    v.mSpatialConstraints->mOrdinalMapping.applyTo(m, x);
+    return !v.mSpatialConstraints->mOrdinalMapping.empty();
+  }
+
   virtual bool visit(const SBase &x)
   {
     if (&x == NULL || x.getPackageName() != "spatial")
@@ -736,10 +752,6 @@ public:
       {
         return visit((const SampledField&)x);
       }
-      else if (code == SBML_SPATIAL_IMAGEDATA)
-      {
-        return visit((const ImageData&)x);
-      }
       else if (code == SBML_SPATIAL_SAMPLEDVOLUME)
       {
         return visit((const SampledVolume&)x);
@@ -840,6 +852,14 @@ public:
       {
         return visit((const CoordinateReference&)x);
       }
+      else if (code == SBML_SPATIAL_MIXEDGEOMETRY)
+      {
+        return visit((const MixedGeometry&)x);
+      }
+      else if (code == SBML_SPATIAL_ORDINALMAPPING)
+      {
+        return visit((const OrdinalMapping&)x);
+      }
       else 
       {
         return SBMLVisitor::visit(x);
@@ -931,15 +951,17 @@ SpatialValidator::validate (const std::string& filename)
   if (&filename == NULL) return 0;
 
   SBMLReader    reader;
-  SBMLDocument& d = *reader.readSBML(filename);
+  SBMLDocument* d = reader.readSBML(filename);
 
 
-  for (unsigned int n = 0; n < d.getNumErrors(); ++n)
+  for (unsigned int n = 0; n < d->getNumErrors(); ++n)
   {
-    logFailure( *d.getError(n) );
+    logFailure( *d->getError(n) );
   }
 
-  return validate(d);
+  unsigned int ret = validate(*d);
+  delete d;
+  return ret;
 }
 
 
