@@ -300,7 +300,7 @@ UnitFormulaFormatter::getUnitDefinition(const ASTNode * node,
   if (ud->getNumUnits() == 0)
   {
     mContainsUndeclaredUnits = true;
-    mCanIgnoreUndeclaredUnits = false;
+    mCanIgnoreUndeclaredUnits = 0;
   }
 
   return ud;
@@ -469,149 +469,61 @@ UnitDefinition *
 UnitFormulaFormatter::getUnitDefinitionFromPower(const ASTNode * node,
                                                  bool inKL, int reactNo)
 { 
+  unsigned int numChildren = node->getNumChildren();
 
-  UnitDefinition * ud;
-  /* this only works is the exponent is an integer - 
-   * since a unit can only have an integral exponent 
-   * but the mathml might do something like
-   * pow(sqrt(m) * 2, 2) - which would be okay
-   * unless we challenge the sqrt(m) !!
-   */
-
-  UnitDefinition * tempUD;
-  UnitDefinition * tempUD2 = NULL;
-  unsigned int i;
-  int newExp = 0;
-  Unit * unit;
-  ASTNode * child;
-  unsigned int found = 0;
-
-  tempUD = getUnitDefinition(node->getLeftChild(), inKL, reactNo);
-  ud = new UnitDefinition(model->getSBMLNamespaces());
-  
-  if (node->getNumChildren() == 1)
-    return ud;
-
-  /** 
-    * if the value set is not an integer need to flag as not to check units
-    */
-  double value = 0.0;
-
-  child = node->getRightChild();
-  for (i = 0; i < tempUD->getNumUnits(); i++)
+  if (numChildren == 0 || numChildren > 2)
   {
-    unit = tempUD->getUnit(i);
-    // need to check type
-    if (child->isInteger()) 
-    {
-      unit->setExponentUnitChecking((int)(child->getInteger() * unit->getExponent()));
-    }
-    else if (child->isName())
-    {
-      /**
-       * if the child is a name then it will be a parameter 
-       * and may be global or local if we are in a kineticLaw
-       * in L3 could be a speciesReference
-       * (if it is a species/compartment units must be messy)
-       */
-      if (inKL == 1)
-      {
-        if (model->getReaction(reactNo)->
-          getKineticLaw()->getParameter(child->getName()))
-        {
-          value = (model->getReaction(reactNo)->
-            getKineticLaw()->getParameter(child->getName()))->getValue();
-          found = 1;
-        }
-      }
-      
-      if (found == 0) // not local parameter
-      {
-        if (model->getParameter(child->getName()))
-        {
-          if (!model->getParameter(child->getName())->isSetValue())
-          {
-            SBMLTransforms::mapComponentValues(model);
-            value = SBMLTransforms::evaluateASTNode(child, model);
-            SBMLTransforms::clearComponentValues();
-          }
-          else
-          {
-            value = model->getParameter(child->getName())->getValue();
-          }
-        }
-        else if (model->getSpeciesReference(child->getName()))
-        {
-          if (!model->getSpeciesReference(child->getName())->isSetStoichiometry())
-          {
-            SBMLTransforms::mapComponentValues(model);
-            value = SBMLTransforms::evaluateASTNode(child, model);
-            SBMLTransforms::clearComponentValues();
-          }
-          else
-          {
-            value = model->getSpeciesReference(child->getName())
-                                                  ->getStoichiometry();
-          }
-        }
-
-      }
-      
-      if (floor(value) != value)
-        mContainsUndeclaredUnits = true;
-      
-      newExp = (int) (value);
-
-      unit->setExponentUnitChecking(newExp * unit->getExponent());
-    }
-    else if (child->isReal())
-    {
-      value = child->getReal();
-      if (floor(value) != value)
-        mContainsUndeclaredUnits = true;
-      newExp = (int) (value);
-      
-      unit->setExponentUnitChecking(newExp * unit->getExponent());
-    }
-    else
-    {
-      tempUD2 = getUnitDefinition(child, inKL, reactNo);
-      UnitDefinition::simplify(tempUD2);
-
-      if (tempUD2->isVariantOfDimensionless())
-      {
-        SBMLTransforms::mapComponentValues(model);
-        value = SBMLTransforms::evaluateASTNode(child);
-        SBMLTransforms::clearComponentValues();
-        if (!util_isNaN(value))
-        {
-          if (floor(value) != value)
-            mContainsUndeclaredUnits = true;
-          newExp = (int) (value);
-          
-          unit->setExponentUnitChecking(newExp * unit->getExponent());
-        }
-        else
-        {
-          mContainsUndeclaredUnits = true;
-        }
-      }
-      else
-      {
-        /* here the child is an expression with units
-        * flag the expression as not checked
-        */
-        mContainsUndeclaredUnits = true;
-      }
-    }
-    ud->addUnit(unit);
+    UnitDefinition * ud = new UnitDefinition(model->getSBMLNamespaces());
+    return ud;
   }
 
-  delete tempUD;
-  if (tempUD2 != NULL)
-    delete tempUD2;
+  UnitDefinition * variableUD = getUnitDefinition(
+                                       node->getLeftChild(), inKL, reactNo);
+
+  if (numChildren == 1)
+  {
+    mContainsUndeclaredUnits = true;
+    return variableUD;
+  }
+
+  // save the undeclared status of variable
+  bool varHasUndeclared = mContainsUndeclaredUnits;
+  unsigned int varCanIgnoreUndeclared = mCanIgnoreUndeclaredUnits;
+
+  double exponentValue = 0.0;
+  ASTNode * exponentNode = node->getRightChild();
+
+  // is the exponent dimensionless or a number because if not it is a problem
+  UnitDefinition* exponentUD = getUnitDefinition(exponentNode, inKL, reactNo);
+  UnitDefinition::simplify(exponentUD);
+
+  if (exponentNode->isInteger() == true ||
+    exponentNode->isReal() == true ||
+    exponentUD->isVariantOfDimensionless())
+  {
+    SBMLTransforms::mapComponentValues(model);
+    exponentValue = SBMLTransforms::evaluateASTNode(node->getRightChild(), model);
+    SBMLTransforms::clearComponentValues();
+
+    for (unsigned int n = 0; n < variableUD->getNumUnits(); n++)
+    {
+      Unit * unit = variableUD->getUnit(n);
+      unit->setExponentUnitChecking(exponentValue * unit->getExponentAsDouble());
+    }
+
+    // restore undeclared status as it should come from variable
+    mContainsUndeclaredUnits = varHasUndeclared;
+    mCanIgnoreUndeclaredUnits = varCanIgnoreUndeclared;
+  }
+  else
+  {
+    mContainsUndeclaredUnits = true;
+  }
+  
+  delete exponentUD;
+
+  return variableUD;
 
-  return ud;
 }
 /* @endcond */
 
@@ -826,16 +738,16 @@ UnitFormulaFormatter::getUnitDefinitionFromArgUnitsReturnFunction
 
   /* get first arg that is not a parameter with undeclared units */
   ud = getUnitDefinition(node->getChild(i), inKL, reactNo);
-  while (getContainsUndeclaredUnits() && mCanIgnoreUndeclaredUnits != 1
+  while (getContainsUndeclaredUnits() == true
     && i < node->getNumChildren()-1)
   {
-    if (originalUndeclaredValue == 1)
+    if (originalUndeclaredValue == true)
       currentIgnore = 0;
     else
       currentIgnore = 1;
 
 
-    currentUndeclared = 1;
+    currentUndeclared = true;
 
     i++;
     delete ud;
@@ -857,7 +769,7 @@ UnitFormulaFormatter::getUnitDefinitionFromArgUnitsReturnFunction
       tempUd = getUnitDefinition(node->getChild(n), inKL, reactNo);
       if (getContainsUndeclaredUnits())
       {
-        currentUndeclared = 1;
+        currentUndeclared = true;
         currentIgnore = 1;
       }
       delete tempUd;
@@ -893,7 +805,7 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
 { 
   UnitDefinition * ud = NULL;
   const UnitDefinition * tempUd;
-  Unit * unit;
+  Unit * unit = NULL;
 
   unsigned int n, found;
   double exponent;
@@ -953,7 +865,7 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
   else if (node->getType() == AST_CONSTANT_PI)
   {
     unit = new Unit(model->getSBMLNamespaces());
-    unit->setKind(UNIT_KIND_RADIAN);
+    unit->setKind(UNIT_KIND_DIMENSIONLESS);
     unit->initDefaults();
     ud   = new UnitDefinition(model->getSBMLNamespaces());
     
@@ -1072,15 +984,13 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
               unit = new Unit(model->getSBMLNamespaces());
               unit->setKind(UnitKind_forName("mole"));
               unit->initDefaults();
-              ud   = new UnitDefinition(model->getSBMLNamespaces());
 
               ud->addUnit(unit);
               delete unit;
+              unit = NULL;
             }
             else
             {
-              ud   = new UnitDefinition(model->getSBMLNamespaces());
-
               for (n = 0; n < tempUd->getNumUnits(); n++)
               {
                 ud->addUnit(tempUd->getUnit(n));
@@ -1101,6 +1011,7 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
               ud->addUnit(unit);
 
               delete unit;
+              unit = NULL;
             }
             else
             {
@@ -1110,6 +1021,7 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
                 exponent = unit->getExponent();
                 unit->setExponentUnitChecking(exponent * -1);
                 ud->addUnit(unit);
+                delete unit;
               }
             }
           }
@@ -1153,7 +1065,7 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
             else
             {
               mContainsUndeclaredUnits = true;
-              mCanIgnoreUndeclaredUnits = false;
+              mCanIgnoreUndeclaredUnits = 0;
             }
 
             std::string timeUnits = model->getTimeUnits();
@@ -1192,7 +1104,7 @@ UnitFormulaFormatter::getUnitDefinitionFromOther(const ASTNode * node,
             else
             {
               mContainsUndeclaredUnits = true;
-              mCanIgnoreUndeclaredUnits = false;
+              mCanIgnoreUndeclaredUnits = 0;
             }
           }
         }
@@ -1629,6 +1541,7 @@ UnitFormulaFormatter::getUnitDefinitionFromSpecies(const Species * species)
     {
       /* compartment units are not defined */
       delete sizeUD;
+      if (subsUD != NULL) delete subsUD;
       return new UnitDefinition(model->getSBMLNamespaces());
     }
   }
@@ -2084,7 +1997,7 @@ UnitFormulaFormatter::getSpeciesSubstanceUnitDefinition(const Species * species)
   }
   
   UnitDefinition * ud = NULL;
-  const UnitDefinition * tempUd;
+  const UnitDefinition * tempUd = NULL;
   Unit * unit = NULL;
   unsigned int n, p;
 
@@ -2133,6 +2046,7 @@ UnitFormulaFormatter::getSpeciesSubstanceUnitDefinition(const Species * species)
       }
 
       delete unit;
+      unit = NULL;
     }
     else
     {
@@ -2157,6 +2071,7 @@ UnitFormulaFormatter::getSpeciesSubstanceUnitDefinition(const Species * species)
       ud->addUnit(unit);
 
       delete unit;
+      unit = NULL;
     }
     else 
     {
@@ -2182,6 +2097,7 @@ UnitFormulaFormatter::getSpeciesSubstanceUnitDefinition(const Species * species)
             ud->addUnit(unit);
 
             delete unit;
+            unit = NULL;
           }
         }
       }
@@ -2203,6 +2119,7 @@ UnitFormulaFormatter::getSpeciesSubstanceUnitDefinition(const Species * species)
         ud->addUnit(unit);
 
         delete unit;
+        unit = NULL;
       }
     }
   }
@@ -2353,6 +2270,7 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
   UnitDefinition * resultUD = NULL;
 
   ASTNode * math = LHS->deepCopy();
+  UnitDefinition * tempUD = expectedUD->clone();
   math->reduceToBinary();
 
   bool isolated = false;
@@ -2363,13 +2281,13 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
   if (numChildren == 0 && math->getType() == AST_NAME
     && math->getName() == id)
   {
-    resultUD = new UnitDefinition(*expectedUD);
+    resultUD = new UnitDefinition(*tempUD);
     isolated = true;
   }
 
   while (isolated == false && numChildren > 0)
   {
-    child1 = math->getChild(0);
+    child1 = math->getChild(0)->deepCopy();
     if (numChildren != 2)
     {
       /* dont support this yet */
@@ -2379,23 +2297,29 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
     }
     else
     {
-      child2 = math->getChild(1);
+      child2 = math->getChild(1)->deepCopy();
     }
 
     if (child1->containsVariable(id) == true)
     {
       if (child1->getType() == AST_NAME && child1->getName() == id)
       {
-        resultUD = inverseFunctionOnUnits(expectedUD, child2, math->getType(),
+        resultUD = inverseFunctionOnUnits(tempUD, child2, math->getType(),
                                           inKL, reactNo);
         isolated = true;
         continue;
       }
       else
       {
-        expectedUD = inverseFunctionOnUnits(expectedUD, child2, math->getType(),
-                                            inKL, reactNo);
-        math = child1;
+        UnitDefinition * tempUD1 = inverseFunctionOnUnits(tempUD, child2, 
+                                              math->getType(), inKL, reactNo);
+        delete tempUD;
+        tempUD = tempUD1->clone();
+        delete tempUD1;
+        delete math;
+        math = child1->deepCopy();
+        if (child1 != NULL) delete child1;
+        if (child2 != NULL) delete child2;
         numChildren = math->getNumChildren();
         continue;
       }
@@ -2404,16 +2328,22 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
     {
       if (child2->getType() == AST_NAME && child2->getName() == id)
       {
-        resultUD = inverseFunctionOnUnits(expectedUD, child1, math->getType(),
+        resultUD = inverseFunctionOnUnits(tempUD, child1, math->getType(),
                                           inKL, reactNo, true);
         isolated = true;
         continue;
       }
       else
       {
-        expectedUD = inverseFunctionOnUnits(expectedUD, child1, math->getType(),
-                                            inKL, reactNo, true);
-        math = child2;
+        UnitDefinition * tempUD1 = inverseFunctionOnUnits(tempUD, child1, 
+                                              math->getType(), inKL, reactNo, true);
+        delete tempUD;
+        tempUD = tempUD1->clone();
+        delete tempUD1;
+        delete math;
+        math = child2->deepCopy();
+        if (child1 != NULL) delete child1;
+        if (child2 != NULL) delete child2;
         numChildren = math->getNumChildren();
         continue;
       }
@@ -2426,6 +2356,11 @@ UnitFormulaFormatter::inferUnitDefinition(UnitDefinition* expectedUD,
     }
   }
 
+  delete math;
+  delete tempUD;
+  if (child1 != NULL) delete child1;
+  if (child2 != NULL) delete child2;
+
   return resultUD;
 }
 
@@ -2491,6 +2426,7 @@ UnitFormulaFormatter::inverseFunctionOnUnits(UnitDefinition* expectedUD,
     break;
   }
 
+  if (mathUD != NULL) delete mathUD;
 
   return resolvedUD;
 }
